@@ -120,7 +120,7 @@ class Convolutions {
 
   static void OneDimensionalGausConvolution(num_t* data, unsigned dataSize,
                                             num_t sigma) {
-    unsigned kernelSize = (unsigned)roundn(sigma * 3.0L);
+    unsigned kernelSize = (unsigned)std::round(sigma * 3.0L);
     if (kernelSize % 2 == 0) ++kernelSize;
     if (kernelSize > dataSize * 2) {
       if (dataSize == 0) return;
@@ -158,7 +158,7 @@ class Convolutions {
     for (unsigned i = 0; i < kernelSize; ++i) {
       const numl_t x = (((numl_t)i - (numl_t)centreElement) * factor);
       if (x != 0.0)
-        kernel[i] = (num_t)(sinnl(x) / x);
+        kernel[i] = (num_t)(std::sin(x) / x);
       else
         kernel[i] = 1.0;
       sum += kernel[i];
@@ -190,10 +190,10 @@ class Convolutions {
     const numl_t hammingFactor = 2.0 * M_PInl * (numl_t)(kernelSize - 1);
     numl_t sum = 0.0;
     for (unsigned i = 0; i < kernelSize; ++i) {
-      const numl_t hamming = 0.54 - 0.46 * cosnl(hammingFactor * (numl_t)i);
+      const numl_t hamming = 0.54 - 0.46 * std::cos(hammingFactor * (numl_t)i);
       const numl_t x = (((numl_t)i - (numl_t)centreElement) * sincFactor);
       if (x != 0.0)
-        kernel[i] = (num_t)(sinnl(x) / x) * hamming;
+        kernel[i] = (num_t)(std::sin(x) / x) * hamming;
       else
         kernel[i] = 1.0;
       sum += kernel[i];
