@@ -25,10 +25,10 @@ void FringeTestCreater::AddStaticFringe(class TimeFrequencyData& ftData,
 
       newReal->SetValue(
           t, channelIndex,
-          strength * cosn(fringeRotation) + real->Value(t, channelIndex));
-      newImaginary->SetValue(
-          t, channelIndex,
-          strength * sinn(fringeRotation) + imaginary->Value(t, channelIndex));
+          strength * std::cos(fringeRotation) + real->Value(t, channelIndex));
+      newImaginary->SetValue(t, channelIndex,
+                             strength * std::sin(fringeRotation) +
+                                 imaginary->Value(t, channelIndex));
     }
   }
 
