@@ -1,5 +1,9 @@
 #include "morphologicalflagger.h"
 
+#include <utility>
+
+namespace algorithms {
+
 bool MorphologicalFlagger::SquareContainsFlag(const Mask2D* mask, size_t xLeft,
                                               size_t yTop, size_t xRight,
                                               size_t yBottom) {
@@ -112,3 +116,5 @@ void MorphologicalFlagger::FlagFrequency(Mask2D* mask, size_t y) {
     mask->SetValue(x, y, true);
   }
 }
+
+}  // namespace algorithms
