@@ -2,6 +2,7 @@
 #define NORMALIZE_PASSBAND_H
 
 #include "../algorithms/thresholdtools.h"
+#include "../structures/timefrequencydata.h"
 
 #include <aocommon/uvector.h>
 
@@ -93,34 +94,58 @@ class NormalizeBandpass {
   }
 
   static void NormalizeSmooth(TimeFrequencyData& data) {
-    TimeFrequencyData real = data.Make(TimeFrequencyData::RealPart),
-                      imag = data.Make(TimeFrequencyData::ImaginaryPart);
     const size_t height = data.ImageHeight();
     aocommon::UVector<double> rms(height);
-    std::vector<std::complex<num_t>> dataVector;
-    for (size_t y = 0; y != height; ++y) {
-      dataVector.resize(data.ImageWidth() * data.ImageCount());
-      auto vecIter = dataVector.begin();
-      const Mask2DCPtr mask = data.GetSingleMask();
-      for (size_t i = 0; i != real.ImageCount(); ++i) {
-        const Image2D& realImage = *real.GetImage(i);
-        const Image2D& imagImage = *imag.GetImage(i);
-        const num_t* realPtr = realImage.ValuePtr(0, y);
-        const num_t* imagPtr = imagImage.ValuePtr(0, y);
-        const bool* maskPtr = mask->ValuePtr(0, y);
-        for (size_t x = 0; x != realImage.Width(); ++x) {
-          if (!*maskPtr && std::isfinite(*realPtr) && std::isfinite(*imagPtr)) {
-            *vecIter = std::complex<num_t>(*realPtr, *imagPtr);
-            ++vecIter;
+    const Mask2DCPtr mask = data.GetSingleMask();
+    if (data.ComplexRepresentation() == TimeFrequencyData::ComplexParts) {
+      TimeFrequencyData real = data.Make(TimeFrequencyData::RealPart);
+      TimeFrequencyData imag = data.Make(TimeFrequencyData::ImaginaryPart);
+      std::vector<std::complex<num_t>> dataVector;
+      for (size_t y = 0; y != height; ++y) {
+        dataVector.resize(data.ImageWidth() * data.ImageCount());
+        auto vecIter = dataVector.begin();
+        for (size_t i = 0; i != real.ImageCount(); ++i) {
+          const Image2D& realImage = *real.GetImage(i);
+          const Image2D& imagImage = *imag.GetImage(i);
+          const num_t* realPtr = realImage.ValuePtr(0, y);
+          const num_t* imagPtr = imagImage.ValuePtr(0, y);
+          const bool* maskPtr = mask->ValuePtr(0, y);
+          for (size_t x = 0; x != realImage.Width(); ++x) {
+            if (!*maskPtr && std::isfinite(*realPtr) &&
+                std::isfinite(*imagPtr)) {
+              *vecIter = std::complex<num_t>(*realPtr, *imagPtr);
+              ++vecIter;
+            }
+            ++realPtr;
+            ++imagPtr;
+            ++maskPtr;
           }
-          ++realPtr;
-          ++imagPtr;
-          ++maskPtr;
         }
-      }
-      dataVector.resize(vecIter - dataVector.begin());
+        dataVector.resize(vecIter - dataVector.begin());
 
-      rms[y] = ThresholdTools::WinsorizedRMS<num_t>(dataVector);
+        rms[y] = ThresholdTools::WinsorizedRMS<num_t>(dataVector);
+      }
+    } else {
+      std::vector<num_t> data_vector;
+      data_vector.reserve(data.ImageWidth() * data.ImageCount());
+      const Mask2DCPtr mask = data.GetSingleMask();
+      for (size_t y = 0; y != height; ++y) {
+        for (size_t i = 0; i != data.ImageCount(); ++i) {
+          const Image2D& image = *data.GetImage(i);
+          const num_t* image_ptr = image.ValuePtr(0, y);
+          const bool* mask_ptr = mask->ValuePtr(0, y);
+          for (size_t x = 0; x != image.Width(); ++x) {
+            if (!*mask_ptr && std::isfinite(*image_ptr)) {
+              data_vector.emplace_back(*image_ptr);
+            }
+            ++image_ptr;
+            ++mask_ptr;
+          }
+        }
+
+        rms[y] = ThresholdTools::WinsorizedRMS<num_t>(data_vector);
+        data_vector.clear();
+      }
     }
 
     for (size_t i = 0; i != data.ImageCount(); ++i) {
@@ -128,12 +153,7 @@ class NormalizeBandpass {
       Image2DPtr destImage =
           Image2D::CreateUnsetImagePtr(image.Width(), image.Height());
       for (size_t y = 0; y != height; ++y) {
-        num_t correctionFactor;
-        if (rms[y] == 0.0)
-          correctionFactor = 0.0;
-        else
-          correctionFactor = 1.0 / rms[y];
-
+        const num_t correctionFactor = (rms[y] == 0.0) ? 0.0 : 1.0 / rms[y];
         const num_t* inputPtr = image.ValuePtr(0, y);
         num_t* destPtr = destImage->ValuePtr(0, y);
         for (size_t x = 0; x < image.Width(); x++) {
