@@ -18,15 +18,15 @@ void SinusFitter::FindPhaseAndAmplitude(num_t& phase, num_t& amplitude,
     const num_t t = dataT[i];
     const num_t x = dataX[i];
 
-    sumR += x * cosn(-t * frequency);
-    sumI += x * sinn(-t * frequency);
+    sumR += x * std::cos(-t * frequency);
+    sumI += x * std::sin(-t * frequency);
   }
 
   sumR /= (num_t)dataSize;
   sumI /= (num_t)dataSize;
 
   phase = Phase(sumR, sumI);
-  amplitude = 2.0L * sqrtn(sumR * sumR + sumI * sumI);
+  amplitude = 2.0L * std::sqrt(sumR * sumR + sumI * sumI);
 }
 
 void SinusFitter::FindPhaseAndAmplitudeComplex(
@@ -40,18 +40,18 @@ void SinusFitter::FindPhaseAndAmplitudeComplex(
     const num_t xR = dataR[i];
     const num_t xI = dataI[i];
 
-    sumR += xR * cosn(-t * frequency);
-    sumR += xI * sinn(-t * frequency);
+    sumR += xR * std::cos(-t * frequency);
+    sumR += xI * std::sin(-t * frequency);
 
-    sumI += xR * sinn(-t * frequency);
-    sumI -= xI * cosn(-t * frequency);
+    sumI += xR * std::sin(-t * frequency);
+    sumI -= xI * std::cos(-t * frequency);
   }
 
   sumR /= (num_t)dataSize;
   sumI /= (num_t)dataSize;
 
   phase = Phase(sumR, sumI);
-  amplitude = sqrtn(sumR * sumR + sumI * sumI);
+  amplitude = std::sqrt(sumR * sumR + sumI * sumI);
 }
 
 num_t SinusFitter::FindMean(const num_t phase, const num_t amplitude,
