@@ -26,7 +26,7 @@ class SinusFitter {
 
   static num_t Value(const num_t phase, const num_t amplitude, const num_t t,
                      const num_t frequency, num_t mean) {
-    return cosn(phase + t * frequency) * amplitude + mean;
+    return std::cos(phase + t * frequency) * amplitude + mean;
   }
 
   /*template<typename T> static T Phase(T real, T imaginary)
@@ -56,10 +56,10 @@ class SinusFitter {
           }
   }*/
   static num_t Phase(num_t real, num_t imaginary) {
-    return atan2n(imaginary, real);
+    return std::atan2(imaginary, real);
   }
   static numl_t Phase(numl_t real, numl_t imaginary) {
-    return atan2nl(imaginary, real);
+    return std::atan2(imaginary, real);
   }
 
  private:
