@@ -275,7 +275,7 @@ void TestSetGenerator::MakeBackground(BackgroundTestSet testSet,
                 for (unsigned x = 0; x < image->Width(); ++x) {
                   image->AddValue(
                       x, y,
-                      sinn(num_t(x) * M_PIn * 5.0 / image->Width()) + 0.1);
+                      std::sin(num_t(x) * M_PIn * 5.0 / image->Width()) + 0.1);
                 }
               }
               break;
@@ -283,13 +283,13 @@ void TestSetGenerator::MakeBackground(BackgroundTestSet testSet,
               for (unsigned y = 0; y < image->Height(); ++y) {
                 for (unsigned x = 0; x < image->Width(); ++x) {
                   image->AddValue(x, y,
-                                  sinn((long double)(x + y * 0.1) * M_PIn *
-                                           5.0L / image->Width() +
-                                       0.1));
+                                  std::sin((long double)(x + y * 0.1) * M_PIn *
+                                               5.0L / image->Width() +
+                                           0.1));
                   image->AddValue(x, y,
-                                  sinn((long double)(x + pown(y, 1.1)) * M_PIn *
-                                           50.0L / image->Width() +
-                                       0.1));
+                                  std::sin((long double)(x + std::pow(y, 1.1)) *
+                                               M_PIn * 50.0L / image->Width() +
+                                           0.1));
                 }
               }
               for (unsigned y = 0; y < image->Height(); ++y) {
