@@ -38,7 +38,7 @@ void ThresholdTools::MeanAndStdDev(const Image2D* image, const Mask2D* mask,
       }
     }
   }
-  stddev = sqrtn(stddev / (num_t)count);
+  stddev = std::sqrt(stddev / (num_t)count);
 }
 
 void ThresholdTools::WinsorizedMeanAndStdDev(const Image2D* image, num_t& mean,
@@ -46,7 +46,7 @@ void ThresholdTools::WinsorizedMeanAndStdDev(const Image2D* image, num_t& mean,
   const size_t size = image->Width() * image->Height();
   num_t* data = new num_t[size];
   image->CopyData(data);
-  std::sort(data, data + size, numLessThanOperator);
+  std::sort(data, data + size, numLessThanOperator<num_t>);
   const size_t lowIndex = (size_t)floor(0.1 * size);
   const size_t highIndex = (size_t)ceil(0.9 * size) - 1;
   const num_t lowValue = data[lowIndex];
@@ -89,7 +89,7 @@ void ThresholdTools::WinsorizedMeanAndStdDev(const Image2D* image, num_t& mean,
     }
   }
   if (count > 0)
-    stddev = sqrtn(1.54 * stddev / (num_t)count);
+    stddev = std::sqrt(1.54 * stddev / (num_t)count);
   else
     stddev = 0.0;
 }
@@ -107,7 +107,7 @@ void ThresholdTools::TrimmedMeanAndStdDev(const std::vector<T>& input, T& mean,
     return;
   }
   std::vector<T> data(input);
-  std::sort(data.begin(), data.end(), numLessThanOperator);
+  std::sort(data.begin(), data.end(), numLessThanOperator<T>);
   const size_t lowIndex = (size_t)floor(0.25 * data.size());
   const size_t highIndex = (size_t)ceil(0.75 * data.size()) - 1;
   T lowValue = data[lowIndex];
@@ -153,7 +153,7 @@ void ThresholdTools::WinsorizedMeanAndStdDev(const std::vector<T>& input,
     stddev = 0.0;
   } else {
     std::vector<T> data(input);
-    std::sort(data.begin(), data.end(), numLessThanOperator);
+    std::sort(data.begin(), data.end(), numLessThanOperator<T>);
     const size_t lowIndex = (size_t)floor(0.1 * data.size());
     const size_t highIndex = (size_t)ceil(0.9 * data.size()) - 1;
     T lowValue = data[lowIndex];
@@ -220,10 +220,10 @@ void ThresholdTools::WinsorizedMeanAndStdDev(const Image2D* image,
   size_t highIndex = (size_t)ceil(0.9 * unflaggedCount);
   if (highIndex > 0) --highIndex;
   std::nth_element(data, data + lowIndex, data + unflaggedCount,
-                   numLessThanOperator);
+                   numLessThanOperator<num_t>);
   const num_t lowValue = data[lowIndex];
   std::nth_element(data, data + highIndex, data + unflaggedCount,
-                   numLessThanOperator);
+                   numLessThanOperator<num_t>);
   const num_t highValue = data[highIndex];
 
   // Calculate mean
@@ -251,7 +251,7 @@ void ThresholdTools::WinsorizedMeanAndStdDev(const Image2D* image,
   }
   delete[] data;
   if (unflaggedCount > 0)
-    stddev = sqrtn(1.54 * stddev / (num_t)unflaggedCount);
+    stddev = std::sqrt(1.54 * stddev / (num_t)unflaggedCount);
   else
     stddev = 0.0;
 }
@@ -276,10 +276,10 @@ void ThresholdTools::WinsorizedMeanAndStdDev(const Image2D* image,
   size_t highIndex = (size_t)ceil(0.9 * unflaggedCount);
   if (highIndex > 0) --highIndex;
   std::nth_element(data.get(), data.get() + lowIndex,
-                   data.get() + unflaggedCount, numLessThanOperator);
+                   data.get() + unflaggedCount, numLessThanOperator<num_t>);
   const num_t lowValue = data[lowIndex];
   std::nth_element(data.get(), data.get() + highIndex,
-                   data.get() + unflaggedCount, numLessThanOperator);
+                   data.get() + unflaggedCount, numLessThanOperator<num_t>);
   const num_t highValue = data[highIndex];
 
   // Calculate mean
@@ -306,7 +306,7 @@ void ThresholdTools::WinsorizedMeanAndStdDev(const Image2D* image,
       stddev += (value - mean) * (value - mean);
   }
   if (unflaggedCount > 0)
-    stddev = sqrtn(1.54 * stddev / (num_t)unflaggedCount);
+    stddev = std::sqrt(1.54 * stddev / (num_t)unflaggedCount);
   else
     stddev = 0.0;
 }
@@ -350,6 +350,47 @@ template double ThresholdTools::WinsorizedRMS(
 template double ThresholdTools::WinsorizedRMS(
     const std::vector<std::complex<double>>& input);
 
+template <typename T>
+double ThresholdTools::WinsorizedRMS(const std::vector<T>& input) {
+  if (input.empty()) {
+    return 0.0;
+  } else {
+    std::vector<T> data(input);
+    const size_t lowIndex = (size_t)floor(0.1 * data.size());
+    const size_t highIndex = (size_t)ceil(0.9 * data.size()) - 1;
+    std::nth_element(data.begin(), data.begin() + lowIndex, data.end(),
+                     numLessThanOperator<T>);
+    const T lowValue = data[lowIndex];
+    std::nth_element(data.begin() + lowIndex, data.begin() + highIndex,
+                     data.end(), numLessThanOperator<T>);
+    const T highValue = data[highIndex];
+
+    // Calculate RMS
+    double rms = 0.0;
+    const double lowValueSquared = lowValue * lowValue;
+    const double highValueSquared = highValue * highValue;
+    size_t count = 0;
+    for (const T& val : data) {
+      if (std::isfinite(val)) {
+        if (numLessThanOperator<T>(val, lowValue))
+          rms += lowValueSquared;
+        else if (numLessThanOperator<T>(highValue, val))
+          rms += highValueSquared;
+        else
+          rms += val * val;
+        count++;
+      }
+    }
+    if (count > 0)
+      return sqrt(1.54 * rms / (T)count);
+    else
+      return 0.0;
+  }
+}
+
+template double ThresholdTools::WinsorizedRMS(const std::vector<float>& input);
+template double ThresholdTools::WinsorizedRMS(const std::vector<double>& input);
+
 num_t ThresholdTools::MinValue(const Image2D* image, const Mask2D* mask) {
   num_t minValue = std::numeric_limits<num_t>::max();
   for (size_t y = 0; y < image->Height(); ++y) {
@@ -487,7 +528,7 @@ num_t ThresholdTools::Mode(const Image2D* image, const Mask2D* mask) {
       }
     }
   }
-  return sqrtn(mode / (2.0 * (num_t)count));
+  return std::sqrt(mode / (2.0 * (num_t)count));
 }
 
 numl_t ThresholdTools::Sum(const Image2D* image, const Mask2D* mask) {
@@ -512,7 +553,7 @@ numl_t ThresholdTools::RMS(const Image2D* image, const Mask2D* mask) {
       }
     }
   }
-  return sqrtnl(mode / (numl_t)count);
+  return std::sqrt(mode / (numl_t)count);
 }
 
 num_t ThresholdTools::WinsorizedMode(const Image2D* image, const Mask2D* mask) {
@@ -545,7 +586,7 @@ num_t ThresholdTools::WinsorizedMode(const Image2D* image, const Mask2D* mask) {
   // the data, meaning that the highest 10% is set to the value exactly at the
   // 90%/10% limit.
   if (unflaggedCount > 0)
-    return sqrtn(mode / (2.0 * (num_t)unflaggedCount)) * 1.0541;
+    return std::sqrt(mode / (2.0 * (num_t)unflaggedCount)) * 1.0541;
   else
     return 0.0;
 }
@@ -578,7 +619,7 @@ num_t ThresholdTools::WinsorizedMode(const Image2D* image, const Mask2D* maskA,
       mode += value * value;
   }
   if (unflaggedCount > 0)
-    return sqrtn(mode / (2.0 * (num_t)unflaggedCount)) * 1.0541;
+    return std::sqrt(mode / (2.0 * (num_t)unflaggedCount)) * 1.0541;
   else
     return 0.0;
 }
@@ -587,7 +628,7 @@ num_t ThresholdTools::WinsorizedMode(const Image2D* image) {
   const size_t size = image->Width() * image->Height();
   num_t* data = new num_t[size];
   image->CopyData(data);
-  std::sort(data, data + size, numLessThanOperator);
+  std::sort(data, data + size, numLessThanOperator<num_t>);
   const size_t highIndex = (size_t)ceil(0.9 * size) - 1;
   const num_t highValue = data[highIndex];
   delete[] data;
@@ -607,7 +648,7 @@ num_t ThresholdTools::WinsorizedMode(const Image2D* image) {
   // the data, meaning that the highest 10% is set to the value exactly at the
   // 90%/10% limit.
   if (size > 0)
-    return sqrtn(mode / (2.0L * (num_t)size)) * 1.0541L;
+    return std::sqrt(mode / (2.0L * (num_t)size)) * 1.0541L;
   else
     return 0.0;
 }
