@@ -11,7 +11,8 @@
 
 #include <limits>
 
-#include <gtkmm/main.h>
+#include <giomm/simpleactiongroup.h>
+
 #include <gtkmm/messagedialog.h>
 
 #include "../structures/msmetadata.h"
@@ -28,65 +29,49 @@
 #include "timefrequencyplotpage.h"
 
 AOQPlotWindow::AOQPlotWindow(AOQPlotController* controller)
-    : _controller(controller),
-      _activeSheetIndex(-1),
-      _pageMenuButton("Sheet"),
-      _baselineMI(_pageGroup, "Baselines"),
-      _antennaeMI(_pageGroup, "Antennae"),
-      _bLengthMI(_pageGroup, "Baseline lengths"),
-      _timeMI(_pageGroup, "Time"),
-      _frequencyMI(_pageGroup, "Frequency"),
-      _timeFrequencyMI(_pageGroup, "Time-frequency"),
-      _summaryMI(_pageGroup, "Summary"),
-      _histogramMI(_pageGroup, "Histograms") {
+    : _controller(controller), _activeSheetIndex(-1), page_menu_button_() {
   set_default_icon_name("aoqplot");
+  page_menu_button_.set_icon_name("open-menu-symbolic");
+  std::shared_ptr<Gio::Menu> page_menu = Gio::Menu::create();
+  page_menu->append("Baselines", "win.page_selection(0)");
+  page_menu->append("Antennae", "win.page_selection(1)");
+  page_menu->append("Baseline lengths", "win.page_selection(2)");
+  page_menu->append("Time", "win.page_selection(3)");
+  page_menu->append("Frequency", "win.page_selection(4)");
+  page_menu->append("Time-frequency", "win.page_selection(5)");
+  page_menu->append("Summary", "win.page_selection(6)");
+  page_menu->append("Histograms", "win.page_selection(7)");
 
-  _toolbar.append(_pageMenuButton);
-  _pageMenuButton.set_menu(_pageMenu);
-  _pageMenu.append(_baselineMI);
-  _baselineMI.signal_toggled().connect(
-      sigc::mem_fun(*this, &AOQPlotWindow::onChangeSheet));
-  _pageMenu.append(_antennaeMI);
-  _antennaeMI.signal_toggled().connect(
-      sigc::mem_fun(*this, &AOQPlotWindow::onChangeSheet));
-  _pageMenu.append(_bLengthMI);
-  _bLengthMI.signal_toggled().connect(
-      sigc::mem_fun(*this, &AOQPlotWindow::onChangeSheet));
-  _pageMenu.append(_timeMI);
-  _timeMI.signal_toggled().connect(
-      sigc::mem_fun(*this, &AOQPlotWindow::onChangeSheet));
-  _pageMenu.append(_frequencyMI);
-  _frequencyMI.signal_toggled().connect(
-      sigc::mem_fun(*this, &AOQPlotWindow::onChangeSheet));
-  _pageMenu.append(_timeFrequencyMI);
-  _timeFrequencyMI.signal_toggled().connect(
-      sigc::mem_fun(*this, &AOQPlotWindow::onChangeSheet));
-  _pageMenu.append(_summaryMI);
-  _summaryMI.signal_toggled().connect(
-      sigc::mem_fun(*this, &AOQPlotWindow::onChangeSheet));
-  _pageMenu.append(_histogramMI);
-  _histogramMI.signal_toggled().connect(
-      sigc::mem_fun(*this, &AOQPlotWindow::onChangeSheet));
-  _pageMenu.show_all_children();
+  auto actions = Gio::SimpleActionGroup::create();
+  page_selection_ =
+      Gio::SimpleAction::create_radio_integer("page_selection", 0);
+  page_selection_->signal_change_state().connect(
+      [this](const Glib::VariantBase& state) {
+        const int value = static_cast<const Glib::Variant<int>&>(state).get();
+        onChangeSheet(value);
+      });
+  actions->add_action(page_selection_);
+  insert_action_group("win", actions);
 
-  _vBox.pack_start(_toolbar, Gtk::PACK_SHRINK);
+  page_menu_button_.set_menu_model(page_menu);
+  toolbar_.append(page_menu_button_);
 
-  _vBox.pack_end(_statusBar, Gtk::PACK_SHRINK);
+  _vBox.append(toolbar_);
+
+  _vBox.append(_statusBar);
   _statusBar.push(
       "Quality plot util is ready. Author: André Offringa "
       "(offringa@gmail.com)");
-
-  add(_vBox);
+  _vBox.set_expand(true);
+  set_child(_vBox);
 
   _openOptionsWindow.SignalOpen().connect(
       sigc::mem_fun(*this, &AOQPlotWindow::onOpenOptionsSelected));
-  signal_hide().connect(sigc::mem_fun(*this, &AOQPlotWindow::onHide));
 
   _controller->Attach(this);
 }
 
 void AOQPlotWindow::Open(const std::vector<std::string>& files) {
-  show_all();
   _openOptionsWindow.ShowForFile(files);
 }
 
@@ -98,7 +83,7 @@ void AOQPlotWindow::onOpenOptionsSelected(const std::vector<std::string>& files,
   _controller->ReadStatistics(files, downsampleTime, downsampleFreq, timeCount,
                               freqCount, correctHistograms);
   _activeSheetIndex = -1;
-  onChangeSheet();
+  onChangeSheet(0);
   show();
 }
 
@@ -107,72 +92,68 @@ void AOQPlotWindow::onStatusChange(const std::string& newStatus) {
   _statusBar.push(newStatus);
 }
 
-void AOQPlotWindow::onChangeSheet() {
-  int selectedSheet = -1;
-  if (_baselineMI.get_active())
-    selectedSheet = 0;
-  else if (_antennaeMI.get_active())
-    selectedSheet = 1;
-  else if (_bLengthMI.get_active())
-    selectedSheet = 2;
-  else if (_timeMI.get_active())
-    selectedSheet = 3;
-  else if (_frequencyMI.get_active())
-    selectedSheet = 4;
-  else if (_timeFrequencyMI.get_active())
-    selectedSheet = 5;
-  else if (_summaryMI.get_active())
-    selectedSheet = 6;
-  else if (_histogramMI.get_active())
-    selectedSheet = 7;
-
+void AOQPlotWindow::onChangeSheet(int selectedSheet) {
   if (selectedSheet != _activeSheetIndex) {
+    if (plot_page_) _vBox.remove(*plot_page_);
+    // In gtk 4, toggle buttons that are part of a group need to be disconnected
+    // from the group before they are removed.
+    auto* child = toolbar_.get_last_child();
+    while (child != &page_menu_button_) {
+      if (Gtk::ToggleButton* toggle = dynamic_cast<Gtk::ToggleButton*>(child);
+          toggle) {
+        toggle->unset_group();
+      }
+      toolbar_.remove(*child);
+      child = toolbar_.get_last_child();
+    }
+
+    page_selection_->set_state(Glib::Variant<int>::create(selectedSheet));
     switch (selectedSheet) {
       case 0:
         _pageController.reset(new BaselinePageController());
-        _activeSheet.reset(new BaselinePlotPage(
+        plot_page_.reset(new BaselinePlotPage(
             static_cast<BaselinePageController*>(_pageController.get())));
         SetStatus("Baseline statistics");
         break;
       case 1:
         _pageController.reset(new AntennaePageController());
-        _activeSheet.reset(new TwoDimensionalPlotPage(
+        plot_page_.reset(new TwoDimensionalPlotPage(
             static_cast<AntennaePageController*>(_pageController.get())));
         SetStatus("Antennae statistics");
         break;
       case 2:
         _pageController.reset(new BLengthPageController());
-        _activeSheet.reset(new BLengthPlotPage(
+        plot_page_.reset(new BLengthPlotPage(
             static_cast<BLengthPageController*>(_pageController.get())));
         SetStatus("Baseline length statistics");
         break;
       case 3:
         _pageController.reset(new TimePageController());
-        _activeSheet.reset(new TwoDimensionalPlotPage(
+        plot_page_.reset(new TwoDimensionalPlotPage(
             static_cast<TimePageController*>(_pageController.get())));
         SetStatus("Time statistics");
         break;
       case 4:
         _pageController.reset(new FrequencyPageController());
-        _activeSheet.reset(new FrequencyPlotPage(
+        plot_page_.reset(new FrequencyPlotPage(
             static_cast<FrequencyPageController*>(_pageController.get())));
         SetStatus("Frequency statistics");
         break;
       case 5:
         _pageController.reset(new TFPageController());
-        _activeSheet.reset(new TimeFrequencyPlotPage(
+        plot_page_.reset(new TimeFrequencyPlotPage(
             static_cast<TFPageController*>(_pageController.get())));
         SetStatus("Time-frequency statistics");
         break;
       case 6:
         _pageController.reset(new SummaryPageController());
-        _activeSheet.reset(new SummaryPage(
+        plot_page_.reset(new SummaryPage(
             static_cast<SummaryPageController*>(_pageController.get())));
         SetStatus("Summary");
         break;
       case 7:
         _pageController.reset(new HistogramPageController());
-        _activeSheet.reset(new HistogramPage(
+        plot_page_.reset(new HistogramPage(
             static_cast<HistogramPageController*>(_pageController.get())));
         SetStatus("Histograms");
         break;
@@ -180,16 +161,16 @@ void AOQPlotWindow::onChangeSheet() {
 
     _activeSheetIndex = selectedSheet;
     _controller->Initialize(_pageController.get(), selectedSheet != 5);
-    _activeSheet->SignalStatusChange().connect(
+    plot_page_->SignalStatusChange().connect(
         sigc::mem_fun(*this, &AOQPlotWindow::onStatusChange));
-    _activeSheet->InitializeToolbar(_toolbar);
-    _toolbar.show_all();
-    _vBox.pack_start(*_activeSheet);
-    _activeSheet->show_all();
+    plot_page_->InitializeToolbar(toolbar_);
+    plot_page_->set_expand(true);
+    _vBox.insert_child_after(*plot_page_, toolbar_);
   }
 }
 
 void AOQPlotWindow::ShowError(const std::string& message) {
-  Gtk::MessageDialog dialog(*this, message, false, Gtk::MESSAGE_ERROR);
-  dialog.run();
+  dialog_ = std::make_unique<Gtk::MessageDialog>(*this, message, false,
+                                                 Gtk::MessageType::ERROR);
+  dialog_->show();
 }
