@@ -5,16 +5,16 @@
 #include <string>
 #include <vector>
 
+#include <giomm/menu.h>
+
 #include <gtkmm/application.h>
+#include <gtkmm/applicationwindow.h>
 #include <gtkmm/box.h>
+#include <gtkmm/dialog.h>
+#include <gtkmm/menubutton.h>
 #include <gtkmm/notebook.h>
 #include <gtkmm/statusbar.h>
-#include <gtkmm/toolbar.h>
-#include <gtkmm/menu.h>
-#include <gtkmm/menutoolbutton.h>
-#include <gtkmm/radiomenuitem.h>
-#include <gtkmm/radiotoolbutton.h>
-#include <gtkmm/window.h>
+#include <gtkmm/togglebutton.h>
 
 #include "../quality/qualitytablesformatter.h"
 
@@ -25,7 +25,7 @@
 
 #include "controllers/aoqpagecontroller.h"
 
-class AOQPlotWindow : public Gtk::Window {
+class AOQPlotWindow : public Gtk::ApplicationWindow {
  public:
   explicit AOQPlotWindow(class AOQPlotController* controller);
 
@@ -39,7 +39,8 @@ class AOQPlotWindow : public Gtk::Window {
 
   void ShowError(const std::string& message);
 
-  void SetShowHistograms(bool show) { _histogramMI.set_sensitive(show); }
+  void SetShowHistograms(bool show) { /*_histogramMI.set_sensitive(show);*/
+  }
 
  private:
   void onOpenOptionsSelected(const std::vector<std::string>& files,
@@ -52,29 +53,24 @@ class AOQPlotWindow : public Gtk::Window {
   void readMetaInfoFromMS(const std::string& filename);
   void readAndCombine(const std::string& filename);
 
-  void onHide() {
-    // Gtk::Application::quit();
-  }
   void onStatusChange(const std::string& newStatus);
 
-  void onChangeSheet();
+  void onChangeSheet(int new_sheet);
 
   class AOQPlotController* _controller;
   int _activeSheetIndex;
-  Gtk::Toolbar _toolbar;
-  Gtk::MenuToolButton _pageMenuButton;
-  Gtk::Menu _pageMenu;
-  Gtk::RadioButtonGroup _pageGroup, _statisticsGroup;
-  Gtk::RadioMenuItem _baselineMI, _antennaeMI, _bLengthMI, _timeMI,
-      _frequencyMI, _timeFrequencyMI, _summaryMI, _histogramMI;
+  Gtk::Box toolbar_;
+  Gtk::MenuButton page_menu_button_;
+  std::shared_ptr<Gio::SimpleAction> page_selection_;
 
-  Gtk::VBox _vBox;
+  Gtk::Box _vBox{Gtk::Orientation::VERTICAL};
   Gtk::Statusbar _statusBar;
 
   std::unique_ptr<AOQPageController> _pageController;
-  std::unique_ptr<PlotSheet> _activeSheet;
+  std::unique_ptr<PlotSheet> plot_page_;
 
   OpenOptionsWindow _openOptionsWindow;
+  std::shared_ptr<Gtk::Dialog> dialog_;
 };
 
 #endif
