@@ -10,7 +10,7 @@ BaselinePlotPage::BaselinePlotPage(BaselinePageController* controller)
       sigc::mem_fun(*this, &BaselinePlotPage::onMouseMoved));
 }
 
-BaselinePlotPage::~BaselinePlotPage() {}
+BaselinePlotPage::~BaselinePlotPage() = default;
 
 void BaselinePlotPage::onMouseMoved(double x, double y) {
   const MaskedHeatMap& map =
