@@ -1,11 +1,6 @@
 #ifndef GUI_QUALITY__BASELINEPLOTPAGE_H
 #define GUI_QUALITY__BASELINEPLOTPAGE_H
 
-#include <gtkmm/box.h>
-#include <gtkmm/window.h>
-#include <gtkmm/frame.h>
-#include <gtkmm/radiobutton.h>
-
 #include "../quality/qualitytablesformatter.h"
 
 #include "grayscaleplotpage.h"
