@@ -1,6 +1,8 @@
 #ifndef GUI_QUALITY__BLENGTHPLOTPAGE_H
 #define GUI_QUALITY__BLENGTHPLOTPAGE_H
 
+#include <gtkmm/togglebutton.h>
+
 #include "twodimensionalplotpage.h"
 
 #include "../structures/msmetadata.h"
@@ -15,7 +17,7 @@ class BLengthPlotPage final : public TwoDimensionalPlotPage {
         _includeAutoCorrelationsButton("Auto-correlations") {}
 
  protected:
-  void addCustomPlotButtons(Gtk::Toolbar& container) override {
+  void addCustomPlotButtons(Gtk::Box& container) override {
     _includeAutoCorrelationsButton.signal_clicked().connect(
         sigc::mem_fun(*this, &BLengthPlotPage::onAutoCorrelationsClicked));
     container.append(_includeAutoCorrelationsButton);
@@ -30,7 +32,7 @@ class BLengthPlotPage final : public TwoDimensionalPlotPage {
   }
 
   BLengthPageController* _controller;
-  Gtk::ToggleToolButton _includeAutoCorrelationsButton;
+  Gtk::ToggleButton _includeAutoCorrelationsButton;
 };
 
 #endif
