@@ -20,10 +20,12 @@ class BaselinePageController final : public HeatMapPageController {
     HeatMap& map = Plot();
     map.SetXAxisDescription("Antenna 1 index");
     map.SetXAxisMin(0);
-    map.SetXAxisMax(antennas.size() - 1);
+    map.SetXAxisMax(antennas.size());
+    map.SetIntegerXAxis(true);
     map.SetYAxisDescription("Antenna 2 index");
     map.SetYAxisMin(0);
-    map.SetYAxisMax(antennas.size() - 1);
+    map.SetYAxisMax(antennas.size());
+    map.SetIntegerYAxis(true);
     UpdateImage();
   }
   void CloseStatistics() override {
