@@ -13,7 +13,7 @@ void DataWindow::SetData(const XYPlot& plot) {
   for (size_t i = 0; i < plot.PointSetCount(); ++i) {
     std::stringstream str;
     str << (i + 1) << ". " << plot.GetPointSet(i).Label();
-    const Gtk::TreeModel::Row row = *_comboListStore->append();
+    Gtk::TreeModel::Row row = *_comboListStore->append();
     row[_comboColumnRecord._comboListNameColumn] = str.str();
   }
   if (selectedIndex < (int)plot.PointSetCount())
