@@ -3,6 +3,8 @@
 
 #include "twodimensionalplotpage.h"
 
+#include <gtkmm/togglebutton.h>
+
 #include "controllers/frequencypagecontroller.h"
 
 #include "../quality/statisticscollection.h"
@@ -15,7 +17,7 @@ class FrequencyPlotPage : public TwoDimensionalPlotPage {
         _controller(controller),
         _ftButton("FT") {}
 
-  void addCustomPlotButtons(Gtk::Toolbar& container) override final {
+  void addCustomPlotButtons(Gtk::Box& container) final {
     _ftButton.signal_clicked().connect(
         sigc::mem_fun(*this, &FrequencyPlotPage::onFTButtonClicked));
     container.append(_ftButton);
@@ -29,7 +31,7 @@ class FrequencyPlotPage : public TwoDimensionalPlotPage {
   }
 
   FrequencyPageController* _controller;
-  Gtk::ToggleToolButton _ftButton;
+  Gtk::ToggleButton _ftButton;
 };
 
 #endif
