@@ -38,146 +38,143 @@ HistogramPage::HistogramPage(HistogramPageController* controller)
       _drawSlope2Button("Draw2"),
       _slopeAutoRangeButton("Auto range"),
       _plotPropertiesWindow(nullptr) {
-  _histogramTypeBox.pack_start(_totalHistogramButton, Gtk::PACK_SHRINK);
+  _histogramTypeBox.append(_totalHistogramButton);
   _totalHistogramButton.set_active(true);
-  _totalHistogramButton.signal_clicked().connect(
+  _totalHistogramButton.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _histogramTypeBox.pack_start(_rfiHistogramButton, Gtk::PACK_SHRINK);
+  _histogramTypeBox.append(_rfiHistogramButton);
   _rfiHistogramButton.set_active(false);
-  _rfiHistogramButton.signal_clicked().connect(
+  _rfiHistogramButton.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _histogramTypeBox.pack_start(_notRFIHistogramButton, Gtk::PACK_SHRINK);
+  _histogramTypeBox.append(_notRFIHistogramButton);
   _notRFIHistogramButton.set_active(false);
-  _notRFIHistogramButton.signal_clicked().connect(
+  _notRFIHistogramButton.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
 
-  _histogramTypeFrame.add(_histogramTypeBox);
+  _histogramTypeFrame.set_child(_histogramTypeBox);
 
-  _sideBox.pack_start(_histogramTypeFrame, Gtk::PACK_SHRINK);
+  _sideBox.append(_histogramTypeFrame);
 
-  _polarizationBox.pack_start(_xxPolarizationButton, Gtk::PACK_SHRINK);
+  _polarizationBox.append(_xxPolarizationButton);
   _xxPolarizationButton.set_active(false);
-  _xxPolarizationButton.signal_clicked().connect(
+  _xxPolarizationButton.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _polarizationBox.pack_start(_xyPolarizationButton, Gtk::PACK_SHRINK);
+  _polarizationBox.append(_xyPolarizationButton);
   _xyPolarizationButton.set_active(false);
-  _xyPolarizationButton.signal_clicked().connect(
+  _xyPolarizationButton.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _polarizationBox.pack_start(_yxPolarizationButton, Gtk::PACK_SHRINK);
+  _polarizationBox.append(_yxPolarizationButton);
   _yxPolarizationButton.set_active(false);
-  _yxPolarizationButton.signal_clicked().connect(
+  _yxPolarizationButton.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _polarizationBox.pack_start(_yyPolarizationButton, Gtk::PACK_SHRINK);
+  _polarizationBox.append(_yyPolarizationButton);
   _yyPolarizationButton.set_active(false);
-  _yyPolarizationButton.signal_clicked().connect(
+  _yyPolarizationButton.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _polarizationBox.pack_start(_sumPolarizationButton, Gtk::PACK_SHRINK);
+  _polarizationBox.append(_sumPolarizationButton);
   _sumPolarizationButton.set_active(true);
-  _sumPolarizationButton.signal_clicked().connect(
+  _sumPolarizationButton.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
 
-  _polarizationFrame.add(_polarizationBox);
+  _polarizationFrame.set_child(_polarizationBox);
 
-  _sideBox.pack_start(_polarizationFrame, Gtk::PACK_SHRINK);
+  _sideBox.append(_polarizationFrame);
 
-  _fitBox.pack_start(_fitButton, Gtk::PACK_SHRINK);
-  _fitButton.signal_clicked().connect(
+  _fitBox.append(_fitButton);
+  _fitButton.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _fitBox.pack_start(_subtractFitButton, Gtk::PACK_SHRINK);
-  _subtractFitButton.signal_clicked().connect(
+  _fitBox.append(_subtractFitButton);
+  _subtractFitButton.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _fitBox.pack_start(_fitLogarithmicButton, Gtk::PACK_SHRINK);
-  _fitLogarithmicButton.signal_clicked().connect(
+  _fitBox.append(_fitLogarithmicButton);
+  _fitLogarithmicButton.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _fitBox.pack_start(_fitAutoRangeButton, Gtk::PACK_SHRINK);
+  _fitBox.append(_fitAutoRangeButton);
   _fitAutoRangeButton.set_active(true);
-  _fitAutoRangeButton.signal_clicked().connect(
+  _fitAutoRangeButton.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::onAutoRangeClicked));
 
-  _fitBox.pack_start(_fitStartEntry, Gtk::PACK_SHRINK);
+  _fitBox.append(_fitStartEntry);
   _fitStartEntry.set_sensitive(false);
   _fitStartEntry.signal_activate().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _fitBox.pack_start(_fitEndEntry, Gtk::PACK_SHRINK);
+  _fitBox.append(_fitEndEntry);
   _fitEndEntry.set_sensitive(false);
   _fitEndEntry.signal_activate().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _fitBox.pack_start(_fitTextView, Gtk::PACK_SHRINK);
+  _fitBox.append(_fitTextView);
 
-  _fitFrame.add(_fitBox);
+  _fitFrame.set_child(_fitBox);
 
-  _sideBox.pack_start(_fitFrame, Gtk::PACK_SHRINK);
+  _sideBox.append(_fitFrame);
 
-  Gtk::RadioButtonGroup group;
-  _functionBox.pack_start(_nsButton, Gtk::PACK_SHRINK);
-  _nsButton.signal_clicked().connect(
+  _functionBox.append(_nsButton);
+  _nsButton.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _nsButton.set_group(group);
-  _functionBox.pack_start(_dndsButton, Gtk::PACK_SHRINK);
-  _dndsButton.signal_clicked().connect(
+  _functionBox.append(_dndsButton);
+  _dndsButton.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _dndsButton.set_group(group);
+  _dndsButton.set_group(_nsButton);
   _nsButton.set_active(true);
-  _functionBox.pack_start(_deltaSEntry, Gtk::PACK_SHRINK);
+  _functionBox.append(_deltaSEntry);
   _deltaSEntry.set_text("2");
   _deltaSEntry.signal_activate().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _functionBox.pack_start(_staircaseFunctionButton, Gtk::PACK_SHRINK);
-  _staircaseFunctionButton.signal_clicked().connect(
+  _functionBox.append(_staircaseFunctionButton);
+  _staircaseFunctionButton.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _functionBox.pack_start(_normalizeButton, Gtk::PACK_SHRINK);
+  _functionBox.append(_normalizeButton);
   _normalizeButton.set_active(true);
-  _normalizeButton.signal_clicked().connect(
+  _normalizeButton.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
 
-  _functionFrame.add(_functionBox);
-  _sideBox.pack_start(_functionFrame, Gtk::PACK_SHRINK);
+  _functionFrame.set_child(_functionBox);
+  _sideBox.append(_functionFrame);
 
   _plotPropertiesButton.signal_clicked().connect(
       sigc::mem_fun(*this, &HistogramPage::onPlotPropertiesClicked));
-  _sideBox.pack_start(_plotPropertiesButton, Gtk::PACK_SHRINK);
+  _sideBox.append(_plotPropertiesButton);
 
   _dataExportButton.signal_clicked().connect(
       sigc::mem_fun(*this, &HistogramPage::onDataExportClicked));
-  _sideBox.pack_start(_dataExportButton, Gtk::PACK_SHRINK);
+  _sideBox.append(_dataExportButton);
 
-  _slopeBox.pack_start(_slopeTextView, Gtk::PACK_SHRINK);
-  _drawSlopeButton.signal_clicked().connect(
+  _slopeBox.append(_slopeTextView);
+  _drawSlopeButton.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _slopeBox.pack_start(_drawSlopeButton, Gtk::PACK_SHRINK);
-  _drawSlope2Button.signal_clicked().connect(
+  _slopeBox.append(_drawSlopeButton);
+  _drawSlope2Button.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _slopeBox.pack_start(_drawSlope2Button, Gtk::PACK_SHRINK);
+  _slopeBox.append(_drawSlope2Button);
 
-  _slopeBox.pack_start(_slopeAutoRangeButton, Gtk::PACK_SHRINK);
+  _slopeBox.append(_slopeAutoRangeButton);
   _slopeAutoRangeButton.set_active(true);
-  _slopeAutoRangeButton.signal_clicked().connect(
+  _slopeAutoRangeButton.signal_toggled().connect(
       sigc::mem_fun(*this, &HistogramPage::onSlopeAutoRangeClicked));
 
-  _slopeBox.pack_start(_slopeStartEntry, Gtk::PACK_SHRINK);
+  _slopeBox.append(_slopeStartEntry);
   _slopeStartEntry.set_sensitive(false);
   _slopeStartEntry.signal_activate().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _slopeBox.pack_start(_slopeEndEntry, Gtk::PACK_SHRINK);
+  _slopeBox.append(_slopeEndEntry);
   _slopeEndEntry.set_sensitive(false);
   _slopeEndEntry.signal_activate().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
-  _slopeBox.pack_start(_slopeRFIRatio, Gtk::PACK_SHRINK);
+  _slopeBox.append(_slopeRFIRatio);
   _slopeRFIRatio.set_text("1.0");
   _slopeRFIRatio.signal_activate().connect(
       sigc::mem_fun(*this, &HistogramPage::updatePlot));
 
-  _slopeFrame.add(_slopeBox);
-  _sideBox.pack_start(_slopeFrame, Gtk::PACK_SHRINK);
+  _slopeFrame.set_child(_slopeBox);
+  _sideBox.append(_slopeFrame);
 
-  _expander.add(_sideBox);
+  _expander.set_child(_sideBox);
 
-  pack_start(_expander, Gtk::PACK_SHRINK);
+  append(_expander);
 
   _plotWidget.SetPlot(_controller->Plot());
-  pack_start(_plotWidget, Gtk::PACK_EXPAND_WIDGET);
-
-  show_all_children();
+  append(_plotWidget);
+  _plotWidget.set_expand(true);
 
   _dataWindow = new DataWindow();
 
@@ -231,13 +228,11 @@ void HistogramPage::onPlotPropertiesClicked() {
         std::bind(&HistogramPage::Redraw, this);
   }
 
-  _plotPropertiesWindow->show();
-  _plotPropertiesWindow->raise();
+  _plotPropertiesWindow->present();
 }
 
 void HistogramPage::onDataExportClicked() {
-  _dataWindow->show();
-  _dataWindow->raise();
+  _dataWindow->present();
   updateDataWindow();
 }
 
