@@ -4,13 +4,13 @@
 #include <string>
 #include <vector>
 
+#include <gtkmm/button.h>
 #include <gtkmm/box.h>
 #include <gtkmm/checkbutton.h>
 #include <gtkmm/entry.h>
 #include <gtkmm/expander.h>
 #include <gtkmm/frame.h>
 #include <gtkmm/textview.h>
-#include <gtkmm/radiobutton.h>
 
 #include "../plot/plotwidget.h"
 
@@ -55,35 +55,35 @@ class HistogramPage : public PlotSheet {
   class HistogramPageController* _controller;
 
   Gtk::Expander _expander;
-  Gtk::VBox _sideBox;
+  Gtk::Box _sideBox{Gtk::Orientation::VERTICAL};
 
   Gtk::Frame _histogramTypeFrame;
-  Gtk::VBox _histogramTypeBox;
+  Gtk::Box _histogramTypeBox{Gtk::Orientation::VERTICAL};
   Gtk::CheckButton _totalHistogramButton, _rfiHistogramButton,
       _notRFIHistogramButton;
 
   Gtk::Frame _polarizationFrame;
-  Gtk::VBox _polarizationBox;
+  Gtk::Box _polarizationBox{Gtk::Orientation::VERTICAL};
   Gtk::CheckButton _xxPolarizationButton, _xyPolarizationButton,
       _yxPolarizationButton, _yyPolarizationButton, _sumPolarizationButton;
 
   Gtk::Frame _fitFrame;
-  Gtk::VBox _fitBox;
+  Gtk::Box _fitBox{Gtk::Orientation::VERTICAL};
   Gtk::CheckButton _fitButton, _subtractFitButton, _fitLogarithmicButton,
       _fitAutoRangeButton;
   Gtk::Entry _fitStartEntry, _fitEndEntry;
   Gtk::TextView _fitTextView;
 
   Gtk::Frame _functionFrame;
-  Gtk::VBox _functionBox;
-  Gtk::RadioButton _nsButton, _dndsButton;
+  Gtk::Box _functionBox{Gtk::Orientation::VERTICAL};
+  Gtk::CheckButton _nsButton, _dndsButton;
   Gtk::Entry _deltaSEntry;
   Gtk::CheckButton _staircaseFunctionButton, _normalizeButton;
 
   Gtk::Button _plotPropertiesButton, _dataExportButton;
 
   Gtk::Frame _slopeFrame;
-  Gtk::VBox _slopeBox;
+  Gtk::Box _slopeBox{Gtk::Orientation::VERTICAL};
   Gtk::TextView _slopeTextView;
   Gtk::CheckButton _drawSlopeButton, _drawSlope2Button;
   Gtk::CheckButton _slopeAutoRangeButton;
