@@ -130,8 +130,8 @@ class SummaryPage : public PlotSheet {
  public:
   explicit SummaryPage(SummaryPageController* controller)
       : _controller(controller) {
-    add(_textView);
-    _textView.show();
+    append(_textView);
+    _textView.set_expand(true);
 
     _controller->Attach(this);
   }
