@@ -12,9 +12,10 @@
 
 #include "plotsheet.h"
 
-#include <gtkmm/toggletoolbutton.h>
-#include <gtkmm/toolbutton.h>
-#include <gtkmm/separatortoolitem.h>
+#include <gtkmm/box.h>
+#include <gtkmm/button.h>
+#include <gtkmm/togglebutton.h>
+#include <gtkmm/separator.h>
 
 #include <set>
 #include <vector>
@@ -24,26 +25,25 @@ class TwoDimensionalPlotPage : public PlotSheet {
   explicit TwoDimensionalPlotPage(AOQPlotPageController* _controller);
   virtual ~TwoDimensionalPlotPage();
 
-  void InitializeToolbar(Gtk::Toolbar& toolbar) override final;
+  void InitializeToolbar(Gtk::Box& toolbar) override final;
 
   std::vector<QualityTablesFormatter::StatisticKind> GetSelectedKinds() const;
-  std::set<enum AOQPlotPageController::SelectedPol> GetSelectedPolarizations()
-      const;
-  std::set<enum AOQPlotPageController::PhaseType> GetSelectedPhases() const;
+  std::set<AOQPlotPageController::SelectedPol> GetSelectedPolarizations() const;
+  std::set<AOQPlotPageController::PhaseType> GetSelectedPhases() const;
 
   void Redraw();
 
  protected:
-  virtual void addCustomPlotButtons(Gtk::Toolbar& container) {}
+  virtual void addCustomPlotButtons(Gtk::Box& container) {}
 
  private:
   void updatePlotConfig();
   void updateDataWindow();
 
-  void initStatisticKindButtons(Gtk::Toolbar& toolbar);
-  void initPolarizationButtons(Gtk::Toolbar& toolbar);
-  void initPhaseButtons(Gtk::Toolbar& toolbar);
-  void initPlotButtons(Gtk::Toolbar& toolbar);
+  void initStatisticKindButtons(Gtk::Box& toolbar);
+  void initPolarizationButtons(Gtk::Box& toolbar);
+  void initPhaseButtons(Gtk::Box& toolbar);
+  void initPlotButtons(Gtk::Box& toolbar);
 
   void onLogarithmicClicked() {
     _zeroAxisButton.set_sensitive(!_logarithmicButton.get_active());
@@ -54,20 +54,19 @@ class TwoDimensionalPlotPage : public PlotSheet {
 
   AOQPlotPageController* _controller;
 
-  Gtk::SeparatorToolItem _separator1, _separator2, _separator3, _separator4;
+  Gtk::Separator _separator1, _separator2, _separator3, _separator4;
 
-  Gtk::ToggleToolButton _countButton, _meanButton, _stdDevButton,
-      _varianceButton, _dCountButton, _dMeanButton, _dStdDevButton,
-      _rfiPercentageButton;
+  Gtk::ToggleButton _countButton, _meanButton, _stdDevButton, _varianceButton,
+      _dCountButton, _dMeanButton, _dStdDevButton, _rfiPercentageButton;
 
-  Gtk::ToggleToolButton _polPPButton, _polPQButton, _polQPButton, _polQQButton,
+  Gtk::ToggleButton _polPPButton, _polPQButton, _polQPButton, _polQQButton,
       _polIButton;
 
-  Gtk::ToggleToolButton _amplitudeButton, _phaseButton, _realButton,
+  Gtk::ToggleButton _amplitudeButton, _phaseButton, _realButton,
       _imaginaryButton;
 
-  Gtk::ToggleToolButton _logarithmicButton, _zeroAxisButton;
-  Gtk::ToolButton _plotPropertiesButton, _dataExportButton;
+  Gtk::ToggleButton _logarithmicButton, _zeroAxisButton;
+  Gtk::Button _plotPropertiesButton, _dataExportButton;
 
   PlotWidget _plotWidget;
 
