@@ -38,7 +38,7 @@ function execute(input)
   -- If the following variable is true, the strategy will consider existing flags
   -- as bad data. It will exclude flagged data from detection, and make sure that any existing
   -- flags on input will be flagged on output. If set to false, existing flags are ignored.
-  local exclude_original_flags = true
+  local use_input_flags = true
   local frequency_resize_factor = 3.0 -- Amount of "extra" smoothing in frequency direction
   local transient_threshold_factor = 1.0 -- decreasing this value makes detection of transient RFI more aggressive
 
@@ -48,7 +48,7 @@ function execute(input)
 
   local inpPolarizations = input:get_polarizations()
 
-  if not exclude_original_flags then
+  if not use_input_flags then
     input:clear_mask()
   end
   -- For collecting statistics. Note that this is done after clear_mask(),
@@ -67,7 +67,7 @@ function execute(input)
         local threshold_factor = threshold_factor_step ^ (iteration_count - i)
 
         local sumthr_level = threshold_factor * base_threshold
-        if exclude_original_flags then
+        if use_input_flags then
           aoflagger.sumthreshold_masked(
             data,
             original_data,
@@ -88,7 +88,7 @@ function execute(input)
 
         -- High pass filtering steps
         data:set_visibilities(original_data)
-        if exclude_original_flags then
+        if use_input_flags then
           data:join_mask(original_data)
         end
 
@@ -110,7 +110,7 @@ function execute(input)
         aoflagger.set_progress((ipol - 1) * iteration_count + i, #flag_polarizations * iteration_count)
       end -- end of iterations
 
-      if exclude_original_flags then
+      if use_input_flags then
         aoflagger.sumthreshold_masked(
           data,
           original_data,
@@ -124,7 +124,7 @@ function execute(input)
       end
     end -- end of complex representation iteration
 
-    if exclude_original_flags then
+    if use_input_flags then
       data:join_mask(original_data)
     end
 
@@ -151,7 +151,7 @@ function execute(input)
     aoflagger.set_progress(ipol, #flag_polarizations)
   end -- end of polarization iterations
 
-  if exclude_original_flags then
+  if use_input_flags then
     aoflagger.scale_invariant_rank_operator_masked(input, copy_of_input, 0.2, 0.2)
   else
     aoflagger.scale_invariant_rank_operator(input, 0.2, 0.2)
