@@ -5,6 +5,9 @@
 
 #Script configuration for this repo. Adjust it when copying to a different repo.
 
+# Disable globbing. This is needed when defining patterns that have wildcards.
+set -e -f
+
 #The directory that contains the source files.
 SOURCE_DIR=$(dirname "$0")/..
 
@@ -12,6 +15,9 @@ SOURCE_DIR=$(dirname "$0")/..
 #relative to SOURCE_DIR.
 EXCLUDE_DIRS=(external build CMake)
 
+#Force using clang-format-14 instead of clang-format
+CLANG_FORMAT_BINARY=clang-format-14
+
 #End script configuration.
 
 #The common formatting script has further documentation.
