@@ -10,8 +10,9 @@
 #include "../util/stopwatch.h"
 #include "joinedspwset.h"
 
-#include <aocommon/parallelfor.h>
+#include <aocommon/dynamicfor.h>
 
+#include <cassert>
 #include <limits>
 #include <numeric>
 #include <utility>
@@ -34,13 +35,14 @@ static std::unique_ptr<BaselineReader> CreateReader(const std::string& ms_name,
     case BaselineIOMode::MemoryReadMode:
       return std::make_unique<MemoryBaselineReader>(ms_name);
   }
+  assert(false);
   return nullptr;
 }
 
 MultiBandMsImageSet::MultiBandMsImageSet(
     const std::vector<std::string>& ms_names, BaselineIOMode io_mode,
-    std::optional<size_t> start_time_step, std::optional<size_t> end_time_step,
-    size_t n_threads)
+    const std::string& data_column_name, std::optional<size_t> start_time_step,
+    std::optional<size_t> end_time_step, size_t n_threads)
     : ms_names_(ms_names) {
   // AutoReadMode behaves as-if MemoryReadMode. When the estimated amount of
   // memory is insufficent switch to the direct reader. This behaviour matches
@@ -52,8 +54,10 @@ MultiBandMsImageSet::MultiBandMsImageSet(
     io_mode = BaselineIOMode::ReorderingReadMode;
 
   for (const std::string& ms_name : ms_names_) {
-    readers_.emplace_back(CreateReader(ms_name, io_mode));
-    readers_.back()->SetInterval(start_time_step, end_time_step);
+    std::unique_ptr<BaselineReader>& reader =
+        readers_.emplace_back(CreateReader(ms_name, io_mode));
+    reader->SetInterval(start_time_step, end_time_step);
+    reader->SetDataColumnName(data_column_name);
   }
 
   assert(n_threads != 0 && n_threads <= readers_.size() &&
@@ -78,7 +82,8 @@ void MultiBandMsImageSet::WriteToMs(size_t n_threads) {
   const Stopwatch watch(true);
 
   const std::vector<BaselineReader*> writers = GetWriters(readers_);
-  aocommon::ParallelFor<size_t> executor(n_threads);
+  aocommon::ThreadPool::GetInstance().SetNThreads(n_threads);
+  aocommon::DynamicFor<size_t> executor;
   executor.Run(0, writers.size(), [&](size_t i) { writers[i]->WriteToMs(); });
 
   Logger::Debug << "Writing took " << watch.ToString() << ".\n";
@@ -175,7 +180,8 @@ static auto ExtractField(const std::vector<const MSMetaData*>& meta_data,
 
 void MultiBandMsImageSet::ReadData(size_t n_threads) {
   const Stopwatch watch(true);
-  aocommon::ParallelFor<size_t> executor(n_threads);
+  aocommon::ThreadPool::GetInstance().SetNThreads(n_threads);
+  aocommon::DynamicFor<size_t> executor;
   executor.Run(0, readers_.size(), [&](size_t i) {
     readers_[i]->PrepareReadWrite(BaselineReader::dummy_progress_);
   });
