@@ -353,8 +353,10 @@ void UVImager::ApplyWeightsToUV() {
 
 void UVImager::SetUVValue(num_t u, num_t v, num_t r, num_t i, num_t weight) {
   // Nearest neighbour interpolation
-  const long uPos = (long)floorn(u * _uvScaling * _xRes + 0.5) + (_xRes / 2);
-  const long vPos = (long)floorn(v * _uvScaling * _yRes + 0.5) + (_yRes / 2);
+  const long uPos =
+      (long)std::floor(u * _uvScaling * _xRes + 0.5) + (_xRes / 2);
+  const long vPos =
+      (long)std::floor(v * _uvScaling * _yRes + 0.5) + (_yRes / 2);
   if (uPos >= 0 && uPos < (long)_xRes && vPos >= 0 && vPos < (long)_yRes) {
     _uvReal.AddValue(uPos, vPos, r);
     _uvImaginary.AddValue(uPos, vPos, i);
@@ -395,7 +397,7 @@ void UVImager::SetUVFTValue(num_t u, num_t v, num_t r, num_t i, num_t weight) {
           ((num_t)iy - (_yResFT / 2)) / _uvScaling * _uvFTReal.Height();
       // Calculate F(x,y) += f(u, v) e ^ {i 2 pi (x u + y v) }
       const num_t fftRotation = (u * x + v * y) * -2.0L * M_PIn;
-      num_t fftCos = cosn(fftRotation), fftSin = sinn(fftRotation);
+      num_t fftCos = std::cos(fftRotation), fftSin = std::sin(fftRotation);
       _uvFTReal.AddValue(ix, iy, (fftCos * r - fftSin * i) * weight);
       _uvFTImaginary.AddValue(ix, iy, (fftSin * r + fftCos * i) * weight);
     }
@@ -436,14 +438,14 @@ void UVImager::GetUVPosition(num_t& u, num_t& v,
   // around x axis
   const num_t raRotation =
       earthLattitudeAngle - pointingLattitude + M_PIn * 0.5L;
-  num_t tmpCos = cosn(raRotation);
-  num_t tmpSin = sinn(raRotation);
+  num_t tmpCos = std::cos(raRotation);
+  num_t tmpSin = std::sin(raRotation);
 
   const num_t dxProjected = tmpCos * cache.dx - tmpSin * cache.dy;
   const num_t tmpdy = tmpSin * cache.dx + tmpCos * cache.dy;
 
-  tmpCos = cosn(-pointingLongitude);
-  tmpSin = sinn(-pointingLongitude);
+  tmpCos = std::cos(-pointingLongitude);
+  tmpSin = std::sin(-pointingLongitude);
   const num_t dyProjected = tmpCos * tmpdy - tmpSin * cache.dz;
   // long double dzProjected = tmpSin*tmpdy + tmpCos*dzAnt; // we don't need it
 
@@ -451,7 +453,7 @@ void UVImager::GetUVPosition(num_t& u, num_t& v,
   // field
 
   num_t baselineLength =
-      sqrtn(dxProjected * dxProjected + dyProjected * dyProjected);
+      std::sqrt(dxProjected * dxProjected + dyProjected * dyProjected);
 
   num_t baselineAngle;
   if (baselineLength == 0.0L) {
@@ -459,13 +461,13 @@ void UVImager::GetUVPosition(num_t& u, num_t& v,
   } else {
     baselineLength /= cache.wavelength;
     if (dxProjected > 0.0L)
-      baselineAngle = atann(dyProjected / dxProjected);
+      baselineAngle = std::atan(dyProjected / dxProjected);
     else
-      baselineAngle = M_PIn - atann(dyProjected / -dxProjected);
+      baselineAngle = M_PIn - std::atan(dyProjected / -dxProjected);
   }
 
-  u = cosn(baselineAngle) * baselineLength;
-  v = -sinn(baselineAngle) * baselineLength;
+  u = std::cos(baselineAngle) * baselineLength;
+  v = -std::sin(baselineAngle) * baselineLength;
 }
 
 num_t UVImager::GetFringeStopFrequency(size_t timeIndex,
@@ -483,7 +485,8 @@ num_t UVImager::GetFringeStopFrequency(size_t timeIndex,
   // num_t dx = baseline.antenna2.x - baseline.antenna1.x;
   // num_t dy = baseline.antenna2.y - baseline.antenna1.y;
   // num_t wavelength = 299792458.0L / frequency;
-  return -earthSpeed * metaData->UVW()[timeIndex].u * cosn(delayDirectionDec);
+  return -earthSpeed * metaData->UVW()[timeIndex].u *
+         std::cos(delayDirectionDec);
 }
 
 num_t UVImager::GetFringeCount(size_t timeIndexStart, size_t timeIndexEnd,
