@@ -12,44 +12,49 @@
 #include "../structures/image2d.h"
 #include "../structures/mask2d.h"
 
-class MemoryBaselineReader : public BaselineReader {
+class MemoryBaselineReader final : public BaselineReader {
  public:
   explicit MemoryBaselineReader(const std::string& msFile)
       : BaselineReader(msFile), _isRead(false), _areFlagsChanged(false) {}
 
   ~MemoryBaselineReader() {
-    if (_areFlagsChanged) writeFlags();
+    if (_areFlagsChanged) {
+      WriteToMs();
+    }
   }
 
-  virtual void PerformReadRequests(
-      class ProgressListener& progress) final override;
+  void PrepareReadWrite(ProgressListener& progress) override;
 
-  virtual void PerformFlagWriteRequests() final override;
+  void PerformReadRequests(class ProgressListener& progress) override;
 
-  virtual void PerformDataWriteTask(
-      std::vector<Image2DCPtr> /*_realImages*/,
-      std::vector<Image2DCPtr> /*_imaginaryImages*/, int /*antenna1*/,
-      int /*antenna2*/, int /*spectralWindow*/,
-      unsigned /*sequenceId*/) final override {
+  void PerformFlagWriteRequests() override;
+
+  void PerformDataWriteTask(
+      [[maybe_unused]] std::vector<Image2DCPtr> realImages,
+      [[maybe_unused]] std::vector<Image2DCPtr> imaginaryImages,
+      [[maybe_unused]] size_t antenna1, [[maybe_unused]] size_t antenna2,
+      [[maybe_unused]] size_t spectralWindow,
+      [[maybe_unused]] size_t sequenceId) override {
     throw std::runtime_error(
         "The full mem reader can not write data back to file: use the indirect "
         "reader");
   }
 
-  static bool IsEnoughMemoryAvailable(const std::string& msFile);
+  static bool IsEnoughMemoryAvailable(uint64_t size);
 
-  virtual size_t GetMinRecommendedBufferSize(
-      size_t /*threadCount*/) final override {
+  size_t GetMinRecommendedBufferSize(size_t /*threadCount*/) override {
     return 1;
   }
-  virtual size_t GetMaxRecommendedBufferSize(
-      size_t /*threadCount*/) final override {
+  size_t GetMaxRecommendedBufferSize(size_t /*threadCount*/) override {
     return 2;
   }
 
+  bool IsModified() const override { return _areFlagsChanged; }
+
+  void WriteToMs() override;
+
  private:
   void readSet(class ProgressListener& progress);
-  void writeFlags();
   void clear();
 
   bool _isRead, _areFlagsChanged;
@@ -63,12 +68,12 @@ class MemoryBaselineReader : public BaselineReader {
     unsigned antenna1, antenna2, spw, sequenceId;
 
     bool operator<(const BaselineID& other) const {
-      if (antenna1 < other.antenna1)
+      if (antenna1 < other.antenna1) {
         return true;
-      else if (antenna1 == other.antenna1) {
-        if (antenna2 < other.antenna2)
+      } else if (antenna1 == other.antenna1) {
+        if (antenna2 < other.antenna2) {
           return true;
-        else if (antenna2 == other.antenna2) {
+        } else if (antenna2 == other.antenna2) {
           if (spw < other.spw)
             return true;
           else if (spw == other.spw)
@@ -82,4 +87,4 @@ class MemoryBaselineReader : public BaselineReader {
   std::map<BaselineID, std::unique_ptr<BaselineReader::Result>> _baselines;
 };
 
-#endif  // DIRECTBASELINEREADER_H
+#endif  // MEMORY_BASELINE_READER_H
