@@ -3,6 +3,7 @@
 #include "colormap.h"
 #include "colorscale.h"
 #include "horizontalplotscale.h"
+#include "statistics.h"
 #include "title.h"
 #include "vectorimage.h"
 #include "verticalplotscale.h"
@@ -11,78 +12,6 @@
 
 #include <cmath>
 
-namespace {
-// We need this less than operator, because the normal operator
-// does not enforce a strictly ordered set, because a<b != !(b<a) in the case
-// of nans/infs.
-bool numLessThanOperator(const float& a, const float& b) {
-  if (std::isfinite(a)) {
-    if (std::isfinite(b))
-      return a < b;
-    else
-      return true;
-  }
-  return false;
-}
-
-void WinsorizedMeanAndStdDev(const ImageInterface& image, float& mean,
-                             float& stddev) {
-  const size_t size = image.Width() * image.Height();
-  std::unique_ptr<float[]> data(new float[size]);
-  const float* imageData = image.Data();
-  for (size_t y = 0; y != image.Height(); ++y) {
-    const float* row = &imageData[y * image.Stride()];
-    std::copy_n(row, image.Width(), &data[y * image.Width()]);
-  }
-  std::sort(data.get(), data.get() + size, numLessThanOperator);
-  const size_t lowIndex = (size_t)std::floor(0.1 * size);
-  const size_t highIndex = (size_t)std::ceil(0.9 * size) - 1;
-  const float lowValue = data[lowIndex];
-  const float highValue = data[highIndex];
-  data.reset();
-
-  // Calculate mean
-  mean = 0.0;
-  size_t count = 0;
-  for (size_t y = 0; y != image.Height(); ++y) {
-    const float* row = &imageData[y * image.Stride()];
-    for (size_t x = 0; x != image.Width(); ++x) {
-      if (std::isfinite(row[x])) {
-        if (row[x] < lowValue)
-          mean += lowValue;
-        else if (row[x] > highValue)
-          mean += highValue;
-        else
-          mean += row[x];
-        count++;
-      }
-    }
-  }
-  if (count > 0) mean /= float(count);
-  // Calculate variance
-  stddev = 0.0;
-  count = 0;
-  for (size_t y = 0; y != image.Height(); ++y) {
-    const float* row = &imageData[y * image.Stride()];
-    for (size_t x = 0; x != image.Width(); ++x) {
-      if (std::isfinite(row[x])) {
-        if (row[x] < lowValue)
-          stddev += (lowValue - mean) * (lowValue - mean);
-        else if (row[x] > highValue)
-          stddev += (highValue - mean) * (highValue - mean);
-        else
-          stddev += (row[x] - mean) * (row[x] - mean);
-        count++;
-      }
-    }
-  }
-  if (count > 0)
-    stddev = std::sqrt(1.54 * stddev / float(count));
-  else
-    stddev = 0.0;
-}
-}  // namespace
-
 #ifndef HAVE_EXP10
 #define exp10(x) exp((2.3025850929940456840179914546844) * (x))
 #endif
@@ -103,6 +32,9 @@ HeatMap::HeatMap()
       _logXScale(false),
       _logYScale(false),
       _logZScale(false),
+      _integerXAxis(false),
+      _integerYAxis(false),
+      _integerZAxis(false),
       _showXAxis(true),
       _showYAxis(true),
       _showX2Axis(false),
@@ -125,7 +57,7 @@ HeatMap::HeatMap()
       _y2AxisMin(1.0),
       _y2AxisMax(10.0),
       _zRange(WinsorizedRange()),
-      _cairoFilter(Cairo::FILTER_NEAREST) {
+      _cairoFilter(Cairo::SurfacePattern::Filter::NEAREST) {
   OnZoomChanged().connect([&]() { _isImageInvalidated = true; });
 }
 
@@ -230,7 +162,8 @@ void HeatMap::SaveSvg(const std::string& filename, size_t width,
 void HeatMap::SavePng(const std::string& filename, size_t width,
                       size_t height) {
   const Cairo::RefPtr<Cairo::ImageSurface> surface =
-      Cairo::ImageSurface::create(Cairo::FORMAT_ARGB32, width, height);
+      Cairo::ImageSurface::create(Cairo::Surface::Format::ARGB32, width,
+                                  height);
   const Cairo::RefPtr<Cairo::Context> cairo = Cairo::Context::create(surface);
   if (HasImage()) {
     PlotBase::Draw(cairo, width, height);
@@ -254,8 +187,10 @@ void HeatMap::drawAll(const Cairo::RefPtr<Cairo::Context>& cairo, size_t width,
   if (_isImageInvalidated) {
     ImageInterface* image = _image.get();
     const int xFactor = ImageToSurfaceXFactor();
+    // Image surfaces can't be larger than 32K
     if (xFactor > 1) {
       scratchImage = ShrinkHorizontally(*image, xFactor);
+      image = scratchImage.get();
       surfaceXRange[0] /= xFactor;
       surfaceXRange[1] /= xFactor;
     }
@@ -263,6 +198,7 @@ void HeatMap::drawAll(const Cairo::RefPtr<Cairo::Context>& cairo, size_t width,
     const int yFactor = ImageToSurfaceYFactor();
     if (yFactor > 1) {
       scratchImage = ShrinkVertically(*image, yFactor);
+      image = scratchImage.get();
       surfaceYRange[0] /= yFactor;
       surfaceYRange[1] /= yFactor;
     }
@@ -376,9 +312,9 @@ void HeatMap::drawAll(const Cairo::RefPtr<Cairo::Context>& cairo, size_t width,
         }
       }
 
-      _imageSurface.clear();
-      _imageSurface = Cairo::ImageSurface::create(Cairo::FORMAT_ARGB32,
-                                                  surfaceWidth, surfaceHeight);
+      _imageSurface.reset();
+      _imageSurface = Cairo::ImageSurface::create(
+          Cairo::ImageSurface::Format::ARGB32, surfaceWidth, surfaceHeight);
 
       _imageSurface->flush();
       unsigned char* data = _imageSurface->get_data();
@@ -447,6 +383,7 @@ void HeatMap::initializeComponents() {
     _horizontalScale.SetAxisType(_xAxisType);
     const bool useLogX = _logXScale && _xAxisMin > 0;
     _horizontalScale.SetLogarithmic(useLogX);
+    _horizontalScale.SetInteger(_integerXAxis);
     _horizontalScale.InitializeTicks();
     _horiScale2.SetAxisType(AxisType::kNumeric);
     _horiScale2.SetTickRange(_x2AxisMin, _x2AxisMax);
@@ -471,6 +408,7 @@ void HeatMap::initializeComponents() {
   if (_showYAxis) {
     _verticalScale.SetDrawWithDescription(_showYAxisDescription);
     _verticalScale.SetLogarithmic(_logYScale && _yAxisMin > 0);
+    _verticalScale.SetInteger(_integerYAxis);
     const double yAxisRange = _yAxisMax - _yAxisMin;
     const std::array<size_t, 2> pixelYRange = ImageYRange();
     if (_logYScale) {
@@ -595,7 +533,8 @@ void HeatMap::downsampleImageBuffer(size_t newWidth, size_t newHeight) {
   const size_t oldHeight = _imageSurface->get_height();
 
   const Cairo::RefPtr<Cairo::ImageSurface> newImageSurface =
-      Cairo::ImageSurface::create(Cairo::FORMAT_ARGB32, newWidth, newHeight);
+      Cairo::ImageSurface::create(Cairo::Surface::Format::ARGB32, newWidth,
+                                  newHeight);
 
   unsigned char* newData = newImageSurface->get_data();
   const size_t rowStrideOfNew = newImageSurface->get_stride();
