@@ -15,6 +15,7 @@ HorizontalPlotScale::HorizontalPlotScale()
       _tickRange({0.0, 1.0}),
       _tickLabels(),
       _isLogarithmic(false),
+      _isInteger(false),
       _rotateUnits(false),
       _drawWithDescription(true),
       _unitsCaption("x"),
@@ -101,11 +102,11 @@ void HorizontalPlotScale::drawDescription(
   cairo->move_to(Data().fromLeft + 0.275 * Data().plotWidth,
                  y - 0.5 * extents.get_height());
   cairo->line_to(Data().fromLeft + 0.25 * Data().plotWidth,
-                 y - 0.1 * extents.get_height());
+                 y - 0.2 * extents.get_height());
   cairo->line_to(Data().fromLeft + 0.26 * Data().plotWidth,
                  y - 0.5 * extents.get_height());
   cairo->line_to(Data().fromLeft + 0.25 * Data().plotWidth,
-                 y - 0.9 * extents.get_height());
+                 y - 0.8 * extents.get_height());
   cairo->close_path();
   cairo->fill();
 }
@@ -217,8 +218,8 @@ void HorizontalPlotScale::InitializeTicks() {
   } else {
     switch (_axisType) {
       case AxisType::kNumeric:
-        _tickSet =
-            std::make_unique<NumericTickSet>(_tickRange[0], _tickRange[1], 25);
+        _tickSet = std::make_unique<NumericTickSet>(
+            _tickRange[0], _tickRange[1], 25, _isInteger);
         break;
       case AxisType::kText:
         _tickSet = std::make_unique<TextTickSet>(_tickLabels, 100);
