@@ -11,7 +11,7 @@ class ImageInterface {
   ImageInterface() : _width(0), _height(0), _stride(0) {}
   ImageInterface(size_t width, size_t height, size_t stride)
       : _width(width), _height(height), _stride(stride) {}
-  virtual ~ImageInterface() {}
+  virtual ~ImageInterface() = default;
   virtual const float* Data() const = 0;
   bool Empty() const { return _width == 0 || _height == 0; }
   size_t Width() const { return _width; }
