@@ -5,13 +5,12 @@
 
 #include <gtkmm/box.h>
 #include <gtkmm/button.h>
-#include <gtkmm/buttonbox.h>
 #include <gtkmm/checkbutton.h>
 #include <gtkmm/entry.h>
+#include <gtkmm/filechooserdialog.h>
 #include <gtkmm/image.h>
 #include <gtkmm/label.h>
 #include <gtkmm/frame.h>
-#include <gtkmm/radiobutton.h>
 #include <gtkmm/scale.h>
 #include <gtkmm/window.h>
 
@@ -51,43 +50,44 @@ class PlotPropertiesWindow : public Gtk::Window {
 
   XYPlot& _plot;
 
-  Gtk::ButtonBox _bottomButtonBox;
-  Gtk::VBox _topVBox;
-  Gtk::HBox _framesHBox;
-  Gtk::VBox _framesRightVBox;
+  Gtk::Box _bottomButtonBox;
+  Gtk::Box _topVBox{Gtk::Orientation::VERTICAL};
+  Gtk::Box _framesHBox;
+  Gtk::Box _framesRightVBox{Gtk::Orientation::VERTICAL};
 
   Gtk::Entry _titleEntry;
 
   Gtk::Button _applyButton, _exportButton, _closeButton;
 
   Gtk::Frame _vRangeFrame;
-  Gtk::VBox _vRangeBox;
-  Gtk::RadioButton _minMaxVRangeButton, _winsorizedVRangeButton,
+  Gtk::Box _vRangeBox{Gtk::Orientation::VERTICAL};
+  Gtk::CheckButton _minMaxVRangeButton, _winsorizedVRangeButton,
       _specifiedVRangeButton;
   Gtk::Label _vRangeMinLabel, _vRangeMaxLabel;
   Gtk::Entry _vRangeMinEntry, _vRangeMaxEntry;
 
   Gtk::Frame _hRangeFrame;
-  Gtk::VBox _hRangeBox;
+  Gtk::Box _hRangeBox{Gtk::Orientation::VERTICAL};
   Gtk::CheckButton _automaticHRangeButton;
   Gtk::Label _hRangeMinLabel, _hRangeMaxLabel;
   Gtk::Entry _hRangeMinEntry, _hRangeMaxEntry;
 
   Gtk::Frame _xOptionsFrame;
-  Gtk::VBox _xOptionsBox;
+  Gtk::Box _xOptionsBox{Gtk::Orientation::VERTICAL};
   Gtk::CheckButton _xLogScaleButton;
 
   Gtk::Frame _yOptionsFrame;
-  Gtk::VBox _yOptionsBox;
-  Gtk::RadioButton _yNormalOptionsButton, _yLogScaleButton,
+  Gtk::Box _yOptionsBox{Gtk::Orientation::VERTICAL};
+  Gtk::CheckButton _yNormalOptionsButton, _yLogScaleButton,
       _yZeroSymmetricButton;
 
   Gtk::Frame _axesDescriptionFrame;
-  Gtk::VBox _axesDescriptionBox;
+  Gtk::Box _axesDescriptionBox{Gtk::Orientation::VERTICAL};
   Gtk::CheckButton _hAxisDescriptionButton, _vAxisDescriptionButton;
   Gtk::Entry _hAxisDescriptionEntry, _vAxisDescriptionEntry;
 
   Gtk::CheckButton _showAxes, _showAxisDescriptionsButton;
+  std::unique_ptr<Gtk::FileChooserDialog> dialog_;
 };
 
 #endif  // PLOTPROPERTIESWINDOW_H
