@@ -9,6 +9,7 @@
 #include <casacore/tables/Tables/ScaColDesc.h>
 #include <casacore/tables/Tables/SetupNewTab.h>
 #include <casacore/tables/Tables/TableRecord.h>
+#include <casacore/tables/Tables/TableUtil.h>
 
 #include <casacore/measures/TableMeasures/TableMeasDesc.h>
 
@@ -147,7 +148,7 @@ void QualityTablesFormatter::RemoveTable(enum QualityTable table) {
     if (_measurementSet->keywordSet().isDefined(TableToName(table)))
       _measurementSet->rwKeywordSet().removeField(TableToName(table));
     if (_measurementSet->isReadable(TableToFilename(table)))
-      casacore::Table::deleteTable(TableToFilename(table));
+      casacore::TableUtil::deleteTable(TableToFilename(table));
   }
 }
 
