@@ -273,8 +273,8 @@ void RFIGuiController::OpenMsConcatenated(
 
   std::unique_ptr<imagesets::ImageSet> image_set =
       std::make_unique<imagesets::MultiBandMsImageSet>(
-          filenames, options.ioMode, options.intervalStart,
-          options.intervalStart, n_io_threads);
+          filenames, options.ioMode, options.dataColumnName,
+          options.intervalStart, options.intervalStart, n_io_threads);
 
   image_set->Initialize();
 
@@ -400,7 +400,7 @@ void RFIGuiController::ExecutePythonStrategy() {
   _rfiGuiWindow->GetTimeFrequencyWidget().Update();
 }
 
-void RFIGuiController::ExecuteLuaStrategy(class ProgressListener& listener) {
+void RFIGuiController::ExecuteLuaStrategy(ProgressListener& listener) {
   _tfController.ClearAllButOriginal();
   _processingThread = std::thread([&]() {
     try {
