@@ -14,7 +14,7 @@ class HistogramWindow : public Gtk::Window {
   explicit HistogramWindow(const HistogramCollection& histograms)
       : _histogramPage(&_controller) {
     _controller.SetHistograms(&histograms);
-    add(_histogramPage);
+    set_child(_histogramPage);
     _histogramPage.show();
   }
   void SetStatistics(const HistogramCollection& histograms) {
