@@ -15,12 +15,12 @@ class StrategyController {
   virtual void SetStrategy(std::unique_ptr<imagesets::Strategy> strategy) = 0;
   virtual imagesets::Strategy& Strategy() = 0;
   virtual void NotifyChange() { _signalOnStrategyChanged(); }
-  virtual sigc::signal<void> SignalOnStrategyChanged() {
+  virtual sigc::signal<void()> SignalOnStrategyChanged() {
     return _signalOnStrategyChanged;
   }
 
  private:
-  sigc::signal<void> _signalOnStrategyChanged;
+  sigc::signal<void()> _signalOnStrategyChanged;
 };
 
 #endif
