@@ -8,27 +8,25 @@
 #include <gtkmm/dialog.h>
 #include <gtkmm/entry.h>
 #include <gtkmm/label.h>
-#include <gtkmm/stock.h>
 
 class NumInputDialog : public Gtk::Dialog {
  public:
-  NumInputDialog(const Glib::ustring& title, const Glib::ustring& valueCaption,
-                 double defaultValue)
-      : Dialog(title, true), _label(valueCaption) {
-    _hBox.pack_start(_label);
+  NumInputDialog(const Glib::ustring& title, Gtk::Window& parent,
+                 const Glib::ustring& valueCaption, double defaultValue)
+      : Dialog(title, parent, true), _label(valueCaption) {
+    _hBox.append(_label);
 
     std::ostringstream s;
     s << defaultValue;
     _entry.set_text(s.str());
     _entry.set_activates_default(true);
-    _hBox.pack_end(_entry);
+    _hBox.append(_entry);
 
-    get_content_area()->pack_start(_hBox);
-    _hBox.show_all();
+    get_content_area()->append(_hBox);
 
-    add_button("_Ok", Gtk::RESPONSE_OK);
-    add_button("_Cancel", Gtk::RESPONSE_CANCEL);
-    set_default_response(Gtk::RESPONSE_OK);
+    add_button("_Ok", Gtk::ResponseType::OK);
+    add_button("_Cancel", Gtk::ResponseType::CANCEL);
+    set_default_response(Gtk::ResponseType::OK);
   }
 
   double Value() const { return atof(_entry.get_text().c_str()); }
@@ -36,7 +34,7 @@ class NumInputDialog : public Gtk::Dialog {
  private:
   Gtk::Label _label;
   Gtk::Entry _entry;
-  Gtk::HBox _hBox;
+  Gtk::Box _hBox;
 };
 
 #endif  // NUMINPUTDIALOG_H
