@@ -1,13 +1,15 @@
 #include "opendialog.h"
 #include "rfiguiwindow.h"
 
-OpenDialog::OpenDialog(RFIGuiWindow& rfiGuiWindow)
-    : _rfiGuiWindow(rfiGuiWindow),
-      _selectButton("Select"),
+#include <gtkmm/error.h>
+
+OpenDialog::OpenDialog(Gtk::Window& parent)
+    : Gtk::Dialog("Open file or measurement set", parent),
+      add_files_button_("Add..."),
       _unselectButton("Unselect"),
       // File tab elements
       _fileScroller(),
-      _fileList(1, false, Gtk::SELECTION_SINGLE),
+      _fileList(1, false, Gtk::SelectionMode::SINGLE),
       // Options tab elements
       _dataColumnLabel("Data column: "),
       _otherColumnLabel("Other column: "),
@@ -15,15 +17,12 @@ OpenDialog::OpenDialog(RFIGuiWindow& rfiGuiWindow)
       _concatenateFrequency("Spectrally concatenate multiple measurement sets"),
       _readingModeLabel("Reading mode: "),
       _readingModeExplanation(
-          "Set how the measurement set is read: in direct mode, the "
-          "information for one baseline is gathered by scanning through the "
-          "entire baseline "
-          "each time a baseline is requested. It is the recommended mode "
-          "for interactive experimentation. The indirect and memory modes "
-          "reorder the baselines "
-          "in a temporary file or memory, respectively, which takes time at "
-          "the start, but allows "
-          "faster browsing through the baselines."),
+          R"(Set how the measurement set is read: in direct mode, the information for one
+baseline is gathered by scanning through the entire baseline each time a
+baseline is requested. It is the recommended mode for interactive
+experimentation. The indirect and memory modes reorder the baselines in a
+temporary file or memory, respectively, which takes time at the start, but
+allows faster browsing through the baselines.)"),
       _baselineAveragingCB("Average baselines together"),
       _baselineAveragingCombo(),
       _baIncludeAutosCB("Include auto-correlations"),
@@ -35,84 +34,73 @@ OpenDialog::OpenDialog(RFIGuiWindow& rfiGuiWindow)
       _intervalExplanation(
           "Limit the timeslots that are read. If only an interval start is "
           "entered, the data set is read to the end.") {
-  get_content_area()->pack_start(_notebook);
-
-  _notebook.append_page(_fileTab, "Files");
-  _fileChooser.signal_file_activated().connect([&]() { onSelectFile(); });
-  _fileChooser.set_size_request(800, 400);
-  _fileTab.pack_start(_fileChooser);
-
-  _unselectButton.set_hexpand(false);
-  _unselectButton.set_vexpand(false);
-  _unselectButton.set_sensitive(false);
-  _unselectButton.signal_clicked().connect([&]() { onUnselectFile(); });
-  _fileButtonBox.pack_start(_unselectButton);
-
-  _selectButton.set_hexpand(false);
-  _selectButton.set_vexpand(false);
-  _selectButton.signal_clicked().connect([&]() { onSelectFile(); });
-  _fileButtonBox.pack_end(_selectButton);
-
-  _fileButtonBox.set_hexpand(false);
-  _fileButtonBox.set_vexpand(false);
-  _fileTab.pack_start(_fileButtonBox, false, false);
+  grid_.set_expand(true);
+  grid_.set_halign(Gtk::Align::FILL);
+  grid_.set_column_spacing(15);
+  grid_.set_row_spacing(5);
+  grid_.set_margin_top(10);
+  grid_.set_margin_start(10);
+  grid_.set_margin_end(10);
+  get_content_area()->append(grid_);
 
   _fileList.set_column_title(0, "Selected file(s)");
   _fileList.set_size_request(0, 100);
   _fileList.get_selection()->signal_changed().connect(
       [&]() { onFileListSelectionChanged(); });
 
-  _fileScroller.add(_fileList);
+  _fileScroller.set_child(_fileList);
 
-  _fileTab.pack_start(_fileScroller);
-
-  _notebook.append_page(_optionsTab, "Options");
-  _optionsTab.set_hexpand(true);
-  _optionsTab.set_halign(Gtk::ALIGN_FILL);
-  _optionsTab.set_column_spacing(15);
-  _optionsTab.set_row_spacing(5);
-  _optionsTab.set_margin_top(10);
-  _optionsTab.set_margin_left(10);
-  _optionsTab.set_margin_right(10);
+  files_box_.append(_fileScroller);
+  files_frame_.set_child(files_box_);
 
   size_t gridRow = 0;
+
+  _unselectButton.set_sensitive(false);
+  _unselectButton.signal_clicked().connect([&]() { onUnselectFile(); });
+  _fileButtonBox.append(_unselectButton);
+
+  add_files_button_.signal_clicked().connect([&]() { OpenFileDialog(); });
+  _fileButtonBox.append(add_files_button_);
+
+  _fileButtonBox.set_halign(Gtk::Align::END);
+  files_box_.append(_fileButtonBox);
+
+  grid_.attach(files_frame_, 0, gridRow, 2, 1);
+  ++gridRow;
+
   initDataColumnButtons(gridRow);
   initReadingModeButtons(gridRow);
   initBaselineAveragingButtons(gridRow);
 
-  _optionsTab.attach(_intervalCB, 0, gridRow, 1, 1);
+  //_optionsTab.attach(_intervalCB, 0, gridRow, 1, 1);
   auto onChange = [&]() {
     const bool enabled = _intervalCB.get_active();
     _intervalStartEntry.set_sensitive(enabled);
     _intervalEndEntry.set_sensitive(enabled);
   };
-  _intervalCB.signal_clicked().connect(onChange);
+  _intervalCB.signal_toggled().connect(onChange);
   onChange();
   _intervalStartEntry.set_width_chars(5);
   _intervalStartEntry.set_text("0");
-  _intervalBox.pack_start(_intervalStartEntry, false, false, 5);
+  _intervalBox.append(_intervalStartEntry);
   _intervalEndEntry.set_width_chars(5);
   _intervalEndEntry.set_text("...");
-  _intervalBox.pack_start(_intervalEndEntry, false, false, 5);
-  _optionsTab.attach(_intervalBox, 1, gridRow, 1, 1);
+  _intervalBox.append(_intervalEndEntry);
+  grid_.attach(_intervalBox, 1, gridRow, 1, 1);
   ++gridRow;
-  _intervalExplanation.set_max_width_chars(80);
-  _intervalExplanation.set_line_wrap(true);
-  _optionsTab.attach(_intervalExplanation, 0, gridRow, 2, 1);
+  grid_.attach(_intervalExplanation, 0, gridRow, 2, 1);
   ++gridRow;
 
-  _optionsTab.attach(_bottomButtonBox, 0, gridRow, 2, 1);
+  grid_.attach(_bottomButtonBox, 0, gridRow, 2, 1);
   ++gridRow;
 
-  get_content_area()->show_all();
-
-  add_button("Cancel", Gtk::RESPONSE_CANCEL);
-  _openButton = add_button("Open", Gtk::RESPONSE_OK);
+  add_button("Cancel", Gtk::ResponseType::CANCEL);
+  _openButton = add_button("Open", Gtk::ResponseType::OK);
   _openButton->set_sensitive(false);
 }
 
 void OpenDialog::initDataColumnButtons(size_t& gridRow) {
-  _optionsTab.attach(_dataColumnLabel, 0, gridRow, 1, 1);
+  grid_.attach(_dataColumnLabel, 0, gridRow, 1, 1);
   _dataColumnCombo.append("DATA");
   _dataColumnCombo.append("CORRECTED_DATA");
   _dataColumnCombo.append("MODEL_DATA");
@@ -124,53 +112,54 @@ void OpenDialog::initDataColumnButtons(size_t& gridRow) {
   });
   _dataColumnCombo.set_active(0);
   _dataColumnCombo.set_hexpand(true);
-  _dataColumnCombo.set_halign(Gtk::ALIGN_FILL);
-  _optionsTab.attach(_dataColumnCombo, 1, gridRow, 1, 1);
+  _dataColumnCombo.set_halign(Gtk::Align::FILL);
+  grid_.attach(_dataColumnCombo, 1, gridRow, 1, 1);
 
-  _otherColumnLabel.set_halign(Gtk::ALIGN_END);
+  _otherColumnLabel.set_halign(Gtk::Align::END);
   _otherColumnGrid.attach(_otherColumnLabel, 0, 0, 1, 1);
   _otherColumnEntry.set_hexpand(true);
-  _otherColumnEntry.set_halign(Gtk::ALIGN_FILL);
+  _otherColumnEntry.set_halign(Gtk::Align::FILL);
   _otherColumnGrid.attach(_otherColumnEntry, 1, 0, 1, 1);
   _otherColumnGrid.set_margin_bottom(10);
-  _optionsTab.attach(_otherColumnGrid, 1, gridRow + 1, 1, 1);
+  grid_.attach(_otherColumnGrid, 1, gridRow + 1, 1, 1);
   gridRow += 2;
-  _optionsTab.attach(_combineSPWsCB, 0, gridRow, 2, 1);
+  grid_.attach(_combineSPWsCB, 0, gridRow, 2, 1);
   _combineSPWsCB.signal_toggled().connect([&] {
     // The Combine SPWs and Concatenate Frequency are mutually exclusive.
     _concatenateFrequency.set_sensitive(!_combineSPWsCB.get_active());
   });
   ++gridRow;
-  _optionsTab.attach(_concatenateFrequency, 0, gridRow, 2, 1);
+  grid_.attach(_concatenateFrequency, 0, gridRow, 2, 1);
   _concatenateFrequency.signal_toggled().connect([&] {
     // The Combine SPWs and Concatenate Frequency are mutually exclusive.
     _combineSPWsCB.set_sensitive(!_concatenateFrequency.get_active());
   });
   ++gridRow;
-  _optionsTab.attach(_columnSeparator, 0, gridRow, 4, 1);
+  grid_.attach(_columnSeparator, 0, gridRow, 4, 1);
   ++gridRow;
 }
 
 void OpenDialog::initReadingModeButtons(size_t& gridRow) {
   _readingModeLabel.set_hexpand(false);
-  _optionsTab.attach(_readingModeLabel, 0, gridRow, 1, 1);
-  _optionsTab.attach(_readingModeCombo, 1, gridRow, 1, 1);
+  grid_.attach(_readingModeLabel, 0, gridRow, 1, 1);
+  grid_.attach(_readingModeCombo, 1, gridRow, 1, 1);
   ++gridRow;
   _readingModeCombo.append("Direct");
   _readingModeCombo.append("Indirect");
   _readingModeCombo.append("Memory");
   _readingModeCombo.set_active(0);
-  _readingModeExplanation.set_line_wrap(true);
-  _readingModeExplanation.set_max_width_chars(80);
-  _readingModeExplanation.set_margin_bottom(10);
-  _optionsTab.attach(_readingModeExplanation, 0, gridRow, 2, 1);
+  grid_.attach(_readingModeExplanation, 0, gridRow, 2, 1);
   ++gridRow;
-  _optionsTab.attach(_readingSeparator, 0, gridRow, 2, 1);
+  //_readingModeExplanation.set_wrap(true);
+  //_readingModeExplanation.set_width_chars(80);
+  //_readingModeExplanation.set_max_width_chars(80);
+  _readingModeExplanation.set_margin_bottom(10);
+  grid_.attach(_readingSeparator, 0, gridRow, 2, 1);
   ++gridRow;
 }
 
 void OpenDialog::initBaselineAveragingButtons(size_t& gridRow) {
-  _optionsTab.attach(_baselineAveragingCB, 0, gridRow, 2, 1);
+  grid_.attach(_baselineAveragingCB, 0, gridRow, 2, 1);
   auto onChange = [&]() {
     const bool enabled = _baselineAveragingCB.get_active();
     _baselineAveragingCombo.set_sensitive(enabled);
@@ -180,7 +169,7 @@ void OpenDialog::initBaselineAveragingButtons(size_t& gridRow) {
     _baTimeDifference.set_sensitive(enabled);
     _baFrequencyDifference.set_sensitive(enabled);
   };
-  _baselineAveragingCB.signal_clicked().connect(onChange);
+  _baselineAveragingCB.signal_toggled().connect(onChange);
   onChange();
   ++gridRow;
   _baselineAveragingCombo.append("Normal average");
@@ -188,24 +177,22 @@ void OpenDialog::initBaselineAveragingButtons(size_t& gridRow) {
   _baselineAveragingCombo.append("Average of squared values");
   _baselineAveragingCombo.append("Standard deviation");
   _baselineAveragingCombo.set_active(0);
-  _optionsTab.attach(_baselineAveragingCombo, 1, gridRow, 1, 1);
+  grid_.attach(_baselineAveragingCombo, 1, gridRow, 1, 1);
   ++gridRow;
-  _optionsTab.attach(_baIncludeAutosCB, 1, gridRow, 1, 1);
+  grid_.attach(_baIncludeAutosCB, 1, gridRow, 1, 1);
   ++gridRow;
-  _optionsTab.attach(_baIncludeFlaggedCB, 1, gridRow, 1, 1);
+  grid_.attach(_baIncludeFlaggedCB, 1, gridRow, 1, 1);
   ++gridRow;
 
-  Gtk::RadioButton::Group group;
-  _baNoDifference.set_group(group);
-  _baTimeDifference.set_group(group);
-  _baFrequencyDifference.set_group(group);
-  _optionsTab.attach(_baNoDifference, 1, gridRow, 1, 1);
+  _baTimeDifference.set_group(_baNoDifference);
+  _baFrequencyDifference.set_group(_baNoDifference);
+  grid_.attach(_baNoDifference, 1, gridRow, 1, 1);
   ++gridRow;
-  _optionsTab.attach(_baTimeDifference, 1, gridRow, 1, 1);
+  grid_.attach(_baTimeDifference, 1, gridRow, 1, 1);
   ++gridRow;
-  _optionsTab.attach(_baFrequencyDifference, 1, gridRow, 1, 1);
+  grid_.attach(_baFrequencyDifference, 1, gridRow, 1, 1);
   ++gridRow;
-  _optionsTab.attach(_baselineAveragingSeparator, 0, gridRow, 2, 1);
+  grid_.attach(_baselineAveragingSeparator, 0, gridRow, 2, 1);
   ++gridRow;
 }
 
@@ -216,10 +203,29 @@ void OpenDialog::SetSelection(const std::vector<std::string>& selection) {
   _openButton->set_sensitive(!_selection.empty());
 }
 
-void OpenDialog::onSelectFile() {
-  _selection.push_back(_fileChooser.get_file()->get_path());
-  _fileList.append(_selection.back());
-  _openButton->set_sensitive(true);
+void OpenDialog::OpenFileDialog() {
+  file_dialog_ = Gtk::FileDialog::create();
+  file_dialog_->set_title("Open data set in rfigui");
+  file_dialog_->select_multiple_folders(
+      [this](Glib::RefPtr<Gio::AsyncResult>& result) {
+        try {
+          auto files = file_dialog_->select_multiple_folders_finish(result);
+          onSelectFile(files);
+        } catch (const Gtk::DialogError&) {
+        }
+        file_dialog_.reset();
+      });
+}
+
+void OpenDialog::onSelectFile(
+    const std::vector<std::shared_ptr<Gio::File>>& files) {
+  if (!files.empty()) {
+    for (const std::shared_ptr<Gio::File>& file : files) {
+      _selection.push_back(file->get_path());
+      _fileList.append(_selection.back());
+    }
+    _openButton->set_sensitive(true);
+  }
 }
 
 void OpenDialog::onUnselectFile() {
@@ -269,29 +275,29 @@ MSOptions OpenDialog::GetOptions() const {
   options.baselineIntegration.enable = _baselineAveragingCB.get_active();
   options.baselineIntegration.withAutos = _baIncludeAutosCB.get_active();
   options.baselineIntegration.withFlagged = _baIncludeFlaggedCB.get_active();
-  options.baselineIntegration.mode = BaselineIntegration::Average;
+  options.baselineIntegration.mode = BaselineIntegrationMode::Average;
   switch (_baselineAveragingCombo.get_active_row_number()) {
     case 0:
-      options.baselineIntegration.mode = BaselineIntegration::Average;
+      options.baselineIntegration.mode = BaselineIntegrationMode::Average;
       break;
     case 1:
-      options.baselineIntegration.mode = BaselineIntegration::AverageAbs;
+      options.baselineIntegration.mode = BaselineIntegrationMode::AverageAbs;
       break;
     case 2:
-      options.baselineIntegration.mode = BaselineIntegration::Squared;
+      options.baselineIntegration.mode = BaselineIntegrationMode::Squared;
       break;
     case 3:
-      options.baselineIntegration.mode = BaselineIntegration::Stddev;
+      options.baselineIntegration.mode = BaselineIntegrationMode::Stddev;
       break;
   }
   if (_baTimeDifference.get_active())
     options.baselineIntegration.differencing =
-        BaselineIntegration::TimeDifference;
+        BaselineIntegrationDifferencing::TimeDifference;
   else if (_baFrequencyDifference.get_active())
     options.baselineIntegration.differencing =
-        BaselineIntegration::FrequencyDifference;
+        BaselineIntegrationDifferencing::FrequencyDifference;
   else
     options.baselineIntegration.differencing =
-        BaselineIntegration::NoDifference;
+        BaselineIntegrationDifferencing::NoDifference;
   return options;
 }
