@@ -9,7 +9,7 @@
 
 class XYPlot;
 
-class PlotFrame : public Gtk::HBox {
+class PlotFrame : public Gtk::Box {
  public:
   PlotFrame();
   ~PlotFrame();
