@@ -8,10 +8,10 @@ PlotWindow::PlotWindow(PlotManager& plotManager)
       _clearButton("_Clear"),
       _editButton("_Edit"),
       _plotPropertiesWindow(nullptr) {
-  Gtk::ToolButton();
   plotManager.OnUpdate() = std::bind(&PlotWindow::handleUpdate, this);
-
-  _hBox.pack_start(_plotWidget, Gtk::PACK_EXPAND_WIDGET);
+  _plotWidget.set_expand(true);
+  _hBox.append(_plotWidget);
+  _hBox.set_expand(true);
 
   _plotListStore = Gtk::ListStore::create(_plotListColumns);
   _plotListView.set_model(_plotListStore);
@@ -29,15 +29,12 @@ PlotWindow::PlotWindow(PlotManager& plotManager)
   _editButton.signal_clicked().connect(
       sigc::mem_fun(*this, &PlotWindow::onEditPlottingPropertiesPressed));
   _toolbar.append(_editButton);
-  _toolbar.set_icon_size(Gtk::ICON_SIZE_SMALL_TOOLBAR);
-  _toolbar.set_toolbar_style(Gtk::TOOLBAR_ICONS);
-  _sideBox.pack_start(_toolbar, Gtk::PACK_SHRINK);
-  _sideBox.pack_start(_plotListView);
+  _sideBox.append(_toolbar);
+  _sideBox.append(_plotListView);
 
-  _hBox.pack_end(_sideBox, false, false, 3);
+  _hBox.append(_sideBox);
 
-  add(_hBox);
-  _hBox.show_all();
+  set_child(_hBox);
 }
 
 PlotWindow::~PlotWindow() { delete _plotPropertiesWindow; }
@@ -62,8 +59,7 @@ void PlotWindow::handleUpdate() {
     delete _plotPropertiesWindow;
     _plotPropertiesWindow = nullptr;
   }
-  show();
-  raise();
+  present();
 }
 
 void PlotWindow::updatePlotList() {
@@ -73,7 +69,7 @@ void PlotWindow::updatePlotList() {
   _plotListStore->clear();
   for (size_t index = 0; index != plots.size(); ++index) {
     const XYPlot& plot = *plots[index];
-    const Gtk::TreeModel::Row row = *_plotListStore->append();
+    Gtk::TreeModel::Row row = *_plotListStore->append();
     row[_plotListColumns._index] = index;
     row[_plotListColumns._name] = plot.GetTitle();
   }
@@ -106,8 +102,7 @@ void PlotWindow::onEditPlottingPropertiesPressed() {
     _plotPropertiesWindow = new PlotPropertiesWindow(plot, "Plot properties");
     _plotPropertiesWindow->OnChangesApplied =
         std::bind(&PlotWindow::onPlotPropertiesChanged, this);
-    _plotPropertiesWindow->show();
-    _plotPropertiesWindow->raise();
+    _plotPropertiesWindow->present();
   }
 }
 
