@@ -5,7 +5,6 @@
 #include <gtkmm/liststore.h>
 #include <gtkmm/treeview.h>
 #include <gtkmm/window.h>
-#include <gtkmm/toolbar.h>
 
 #include "../plot/plotwidget.h"
 
@@ -38,10 +37,10 @@ class PlotWindow : public Gtk::Window {
 
   PlotWidget _plotWidget;
   class PlotManager& _plotManager;
-  Gtk::HBox _hBox;
-  Gtk::VBox _sideBox;
-  Gtk::Toolbar _toolbar;
-  Gtk::ToolButton _clearButton, _editButton;
+  Gtk::Box _hBox;
+  Gtk::Box _sideBox{Gtk::Orientation::VERTICAL};
+  Gtk::Box _toolbar;
+  Gtk::Button _clearButton, _editButton;
   Glib::RefPtr<Gtk::ListStore> _plotListStore;
   Gtk::TreeView _plotListView;
   class PlotPropertiesWindow* _plotPropertiesWindow;
