@@ -2,7 +2,6 @@
 
 #include <gtkmm/aboutdialog.h>
 #include <gtkmm/filechooserdialog.h>
-#include <gtkmm/icontheme.h>
 #include <gtkmm/messagedialog.h>
 
 #include <filesystem>
@@ -25,6 +24,7 @@
 #include "../algorithms/resampling.h"
 #include "../algorithms/thresholdtools.h"
 #include "../algorithms/timefrequencystatistics.h"
+#include "../algorithms/sisco/predictresidual.h"
 
 #include "controllers/imagecomparisoncontroller.h"
 #include "controllers/rfiguicontroller.h"
@@ -32,10 +32,12 @@
 #include "gotowindow.h"
 #include "histogramwindow.h"
 #include "imagepropertieswindow.h"
+#include "initialization.h"
 #include "numinputdialog.h"
 #include "opendialog.h"
 #include "plotwindow.h"
 #include "progresswindow.h"
+#include "rangeinputdialog.h"
 #include "rfiguimenu.h"
 #include "simulatedialog.h"
 
@@ -54,35 +56,19 @@ using algorithms::ThresholdConfig;
 using algorithms::ThresholdTools;
 using algorithms::TimeFrequencyStatistics;
 
-RFIGuiWindow::RFIGuiWindow(RFIGuiController* controller,
-                           const std::string& argv0)
+RFIGuiWindow::RFIGuiWindow(RFIGuiController* controller)
     : _controller(controller),
-      _mainVBox(Gtk::ORIENTATION_VERTICAL),
+      _mainVBox(Gtk::Orientation::VERTICAL),
       _timeFrequencyWidget(_controller->TFController().Plot()),
       _plotWindow(new PlotWindow(_controller->PlotManager())),
       _menu() {
   _controller->AttachWindow(this);
 
-  const Glib::RefPtr<Gtk::IconTheme> iconTheme = Gtk::IconTheme::get_default();
-
-  const std::filesystem::path argv0Root =
-      std::filesystem::path(argv0).remove_filename();
-  if (!std::filesystem::equivalent(
-          argv0Root / "..", std::filesystem::path(AOFLAGGER_INSTALL_PATH))) {
-    const std::filesystem::path iconPathC =
-        std::filesystem::path(AOFLAGGER_INSTALL_PATH) / "share/icons";
-    iconTheme->prepend_search_path(iconPathC.string());
-  }
-  const std::filesystem::path iconPathA = argv0Root / "../share/icons";
-  iconTheme->prepend_search_path(iconPathA.string());
-  const std::filesystem::path iconPathB = argv0Root / "../data/icons";
-  iconTheme->prepend_search_path(iconPathB.string());
-
-  // Now that the icon search path is correct, the menu can be created
-  _menu.reset(new RFIGuiMenu());
+  _menu.reset(new RFIGuiMenu(*this));
 
   set_default_size(800, 600);
   set_default_icon_name("aoflagger");
+  _plotWindow->set_hide_on_close(true);
 
   _menu->SetOriginalFlagsActive(_controller->AreOriginalFlagsShown());
   _menu->SetAlternativeFlagsActive(_controller->AreAlternativeFlagsShown());
@@ -90,7 +76,7 @@ RFIGuiWindow::RFIGuiWindow(RFIGuiController* controller,
   // File
   _menu->OnOpen.connect([&]() { onOpen(); });
   _menu->OnSaveBaselineFlags.connect([&]() { onSaveBaselineFlags(); });
-  _menu->OnClose.connect([&]() { onClose(); });
+  _menu->OnClose.connect([&]() { onCloseFile(); });
   _menu->OnExportBaseline.connect([&]() { onExportBaseline(); });
   _menu->OnQuit.connect([&]() { onQuit(); });
   _menu->OnAbout.connect([&]() { onHelpAbout(); });
@@ -202,6 +188,7 @@ RFIGuiWindow::RFIGuiWindow(RFIGuiController* controller,
 
   _menu->OnTemporalAveragingPressed.connect([&]() { handleAveraging(false); });
   _menu->OnSpectralAveragingPressed.connect([&]() { handleAveraging(true); });
+  _menu->OnPredictResidual.connect([&]() { predictResidual(); });
 
   // Actions
   _menu->OnSegment.connect([&]() { onSegment(); });
@@ -214,10 +201,11 @@ RFIGuiWindow::RFIGuiWindow(RFIGuiController* controller,
   _menu->OnToggleImage.connect([&]() { onToggleImage(); });
   _menu->OnSelectImage.connect([&]() { onSelectImage(); });
 
-  _mainVBox.pack_start(_menu->Menu(), Gtk::PACK_SHRINK);
-  _mainVBox.pack_start(_menu->Toolbar(), Gtk::PACK_SHRINK);
+  _mainVBox.append(_menu->Menu());
+  _mainVBox.append(_menu->Toolbar());
 
-  _mainVBox.pack_start(_timeFrequencyWidget, Gtk::PACK_EXPAND_WIDGET);
+  _mainVBox.append(_timeFrequencyWidget);
+  _timeFrequencyWidget.set_expand(true);
   _timeFrequencyWidget.GetHeatMapWidget().OnMouseMovedEvent().connect(
       sigc::mem_fun(*this, &RFIGuiWindow::onTFWidgetMouseMoved));
   _timeFrequencyWidget.GetHeatMapWidget().OnMouseLeaveEvent().connect(
@@ -234,16 +222,17 @@ RFIGuiWindow::RFIGuiWindow(RFIGuiController* controller,
 
   _strategyEditor.SetText(_controller->GetWorkStrategyText());
   _strategyEditor.ResetChangedStatus();
-  _mainVBox.pack_start(_strategyEditor, Gtk::PACK_EXPAND_WIDGET);
+  _strategyEditor.set_expand(true);
+  _mainVBox.append(_strategyEditor);
+  _mainVBox.set_expand(true);
 
   _controller->TFController().VisualizationListChange().connect(
       sigc::mem_fun(*this, &RFIGuiWindow::updateTFVisualizationMenu));
 
-  _mainVBox.pack_end(_statusbar, Gtk::PACK_SHRINK);
+  _mainVBox.append(_statusbar);
   _statusbar.push("Ready. For suggestions, contact offringa@gmail.com .");
 
-  add(_mainVBox);
-  _mainVBox.show_all();
+  set_child(_mainVBox);
   _strategyEditor.hide();
   _timeFrequencyWidget.DisableTimePlot();
 
@@ -259,48 +248,66 @@ RFIGuiWindow::RFIGuiWindow(RFIGuiController* controller,
   updateRecentFiles();
   updateOpenStrategyMenu();
 
-  signal_delete_event().connect(
-      [&](GdkEventAny* event) { return onClose(event); });
+  signal_close_request().connect(
+      [&]() {
+        if (_strategyEditor.IsChanged()) {
+          askToSaveChanges([this]() { hide(); });
+          return true;
+        } else {
+          return false;
+        }
+      },
+      false);
 }
 
-RFIGuiWindow::~RFIGuiWindow() {}
+RFIGuiWindow::~RFIGuiWindow() = default;
 
-bool RFIGuiWindow::onClose(GdkEventAny* event) { return !askToSaveChanges(); }
-
-bool RFIGuiWindow::askToSaveChanges() {
+void RFIGuiWindow::askToSaveChanges(
+    std::function<void()> continuation_function) {
   if (_strategyEditor.IsChanged()) {
-    Gtk::MessageDialog dialog(
+    dialog_ = std::make_unique<Gtk::MessageDialog>(
+        *this,
         "The strategy was changed without saving. Do you want to save your "
         "changes?",
-        false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE);
-    dialog.add_button("Don't save", Gtk::RESPONSE_CLOSE);
-    dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
-    dialog.add_button(Gtk::Stock::SAVE, Gtk::RESPONSE_YES);
-    const int result = dialog.run();
-    if (result == Gtk::RESPONSE_CANCEL) {
-      return false;
-    } else if (result == Gtk::RESPONSE_CLOSE) {
-      return true;
-    } else {
-      onStrategySave();
-      // In case the strategy had no name yet, the onStrategySave() call will
-      // show a file dialog where the user might press cancel. In that case,
-      // the operation is cancelled:
-      return !_strategyEditor.IsChanged();
-    }
+        false, Gtk::MessageType::QUESTION, Gtk::ButtonsType::NONE);
+    Gtk::MessageDialog& dialog = static_cast<Gtk::MessageDialog&>(*dialog_);
+    dialog.add_button("Don't save", Gtk::ResponseType::CLOSE);
+    dialog.add_button("Cancel", Gtk::ResponseType::CANCEL);
+    dialog.add_button("Save", Gtk::ResponseType::YES);
+    dialog.signal_response().connect(
+        [this, continuation_function](int response) {
+          dialog_.reset();
+          if (response == Gtk::ResponseType::CANCEL) {
+            // nothing to do
+          } else if (response == Gtk::ResponseType::CLOSE) {
+            continuation_function();
+          } else {
+            onStrategySave();
+          }
+        });
+    dialog.show();
   } else {
-    return true;
+    continuation_function();
   }
 }
 
 void RFIGuiWindow::onOpen() {
-  OpenDialog openDialog(*this);
+  dialog_ = std::make_unique<OpenDialog>(*this);
 
-  const int result = openDialog.run();
-
-  if (result == Gtk::RESPONSE_OK) {
-    OpenMS(openDialog.Selection(), openDialog.GetOptions());
-  }
+  dialog_->signal_response().connect([this](int response) {
+    if (response == Gtk::ResponseType::OK) {
+      OpenDialog& open_dialog = static_cast<OpenDialog&>(*dialog_);
+      std::vector<std::string> selection = open_dialog.Selection();
+      const MSOptions options = open_dialog.GetOptions();
+      dialog_.reset();
+      OpenMS(selection, options);
+    } else {
+      dialog_.reset();
+    }
+  });
+  OpenDialog& open_dialog = static_cast<OpenDialog&>(*dialog_);
+  open_dialog.OpenFileDialog();
+  open_dialog.show();
 }
 
 void RFIGuiWindow::onOpenRecent(size_t index) {
@@ -330,14 +337,16 @@ void RFIGuiWindow::updateOpenStrategyMenu() {
   _menu->SetStrategyDefaults(strategies);
 }
 
-void RFIGuiWindow::onClose() { _controller->CloseImageSet(); }
+void RFIGuiWindow::onCloseFile() { _controller->CloseImageSet(); }
 
 void RFIGuiWindow::onExportBaseline() {
-  Gtk::FileChooserDialog dialog("Select baseline file",
-                                Gtk::FILE_CHOOSER_ACTION_SAVE);
+  dialog_ = std::make_unique<Gtk::FileChooserDialog>(
+      "Select baseline file", Gtk::FileChooser::Action::SAVE);
+  Gtk::FileChooserDialog& dialog =
+      static_cast<Gtk::FileChooserDialog&>(*dialog_);
   dialog.set_transient_for(*this);
-  dialog.add_button("_Cancel", Gtk::RESPONSE_CANCEL);
-  dialog.add_button("_Save", Gtk::RESPONSE_ACCEPT);
+  dialog.add_button("_Cancel", Gtk::ResponseType::CANCEL);
+  dialog.add_button("_Save", Gtk::ResponseType::ACCEPT);
 
   auto filter_rfibl = Gtk::FileFilter::create();
   filter_rfibl->set_name("Baseline files (*.rfibl)");
@@ -351,27 +360,38 @@ void RFIGuiWindow::onExportBaseline() {
   filter_npy->add_pattern("*.npy");
   dialog.add_filter(filter_npy);
 
-  dialog.set_do_overwrite_confirmation(true);
-  const int result = dialog.run();
+  dialog.signal_response().connect([this, filter_rfibl](int response) {
+    if (response == Gtk::ResponseType::ACCEPT) {
+      Gtk::FileChooserDialog& dialog =
+          static_cast<Gtk::FileChooserDialog&>(*dialog_);
+      if (dialog.get_filter() == filter_rfibl)
+        _controller->SaveBaselineAsRfibl(dialog.get_file()->get_path());
+      else
+        _controller->SaveBaselineAsNpy(dialog.get_file()->get_path());
+    }
+    dialog_.reset();
+  });
 
-  if (result == Gtk::RESPONSE_ACCEPT) {
-    if (dialog.get_filter() == filter_rfibl)
-      _controller->SaveBaselineAsRfibl(dialog.get_filename());
-    else
-      _controller->SaveBaselineAsNpy(dialog.get_filename());
-  }
+  dialog.show();
 }
 
 void RFIGuiWindow::OpenPaths(const std::vector<std::string>& paths) {
   if (paths.size() > 1 || imagesets::ImageSet::IsMSFile(paths.front())) {
-    OpenDialog openDialog(*this);
-    openDialog.SetSelection(paths);
-    openDialog.ActivateOptionsTab();
-    const int result = openDialog.run();
-
-    if (result == Gtk::RESPONSE_OK) {
-      OpenMS(openDialog.Selection(), openDialog.GetOptions());
-    }
+    dialog_ = std::make_unique<OpenDialog>(*this);
+    OpenDialog& open_dialog = static_cast<OpenDialog&>(*dialog_);
+    open_dialog.SetSelection(paths);
+    open_dialog.signal_response().connect([this](int response) {
+      if (response == Gtk::ResponseType::OK) {
+        OpenDialog& open_dialog = static_cast<OpenDialog&>(*dialog_);
+        std::vector<std::string> selection = open_dialog.Selection();
+        const MSOptions options = open_dialog.GetOptions();
+        dialog_.reset();
+        OpenMS(selection, options);
+      } else {
+        dialog_.reset();
+      }
+    });
+    open_dialog.show();
   } else {
     _controller->Open(paths);
 
@@ -394,18 +414,22 @@ void RFIGuiWindow::OpenMS(const std::vector<std::string>& filenames,
     else
       loadWithProgress();
   } catch (std::exception& e) {
-    Gtk::MessageDialog dialog(*this, e.what(), false, Gtk::MESSAGE_ERROR);
-    dialog.run();
+    dialog_ = std::make_unique<Gtk::MessageDialog>(*this, e.what(), false,
+                                                   Gtk::MessageType::ERROR);
+    dialog_->show();
   }
 }
 
 void RFIGuiWindow::onSaveBaselineFlags() {
-  Gtk::MessageDialog dialog(*this,
-                            "Are you sure you want to change the currently "
-                            "opened dataset and write the flags as displayed?",
-                            false, Gtk::MESSAGE_QUESTION,
-                            Gtk::BUTTONS_OK_CANCEL, true);
-  if (dialog.run() == Gtk::RESPONSE_OK) _controller->SaveBaselineFlags();
+  dialog_ = std::make_unique<Gtk::MessageDialog>(
+      *this,
+      "Are you sure you want to change the currently "
+      "opened dataset and write the flags as displayed?",
+      false, Gtk::MessageType::QUESTION, Gtk::ButtonsType::OK_CANCEL, true);
+  dialog_->signal_response().connect([this](int response) {
+    dialog_.reset();
+    if (response == Gtk::ResponseType::OK) _controller->SaveBaselineFlags();
+  });
 }
 
 TimeFrequencyData RFIGuiWindow::GetActiveData() const {
@@ -533,8 +557,10 @@ void RFIGuiWindow::onExecuteStrategyError(const std::string& error) {
     const size_t lineNr = std::atoi(error.substr(colon + 1).c_str());
     _strategyEditor.HighlightLine(lineNr);
   }
-  Gtk::MessageDialog dialog(*this, error, false, Gtk::MESSAGE_ERROR);
-  dialog.run();
+  dialog_ = std::make_unique<Gtk::MessageDialog>(*this, error, false,
+                                                 Gtk::MessageType::ERROR);
+  dialog_->signal_response().connect([this](int) { dialog_.reset(); });
+  dialog_->show();
 }
 
 void RFIGuiWindow::openTestSet(algorithms::RFITestSet rfiSet,
@@ -652,49 +678,41 @@ void RFIGuiWindow::onSetToOnePlusI() {
 }
 
 void RFIGuiWindow::onAddCorrelatorFault() {
-  Gtk::MessageDialog dialog(*this, "Enter affected timerange (ratios):", false,
-                            Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL,
-                            true);
-  Gtk::Entry startTime;
-  Gtk::Box hBox;
-  startTime.set_text("0.25");
-  hBox.pack_start(startTime);
-  Gtk::Label dashLabel("-");
-  hBox.pack_start(dashLabel);
-  Gtk::Entry endTime;
-  endTime.set_text("0.5");
-  hBox.pack_start(endTime);
-  Gtk::Box* box = dialog.get_content_area();
-  box->pack_start(hBox);
-  box->show_all_children();
-  if (dialog.run() == Gtk::RESPONSE_OK) {
-    TimeFrequencyData data(GetActiveData());
-    const double startRatio = std::atof(startTime.get_text().c_str());
-    const double endRatio = std::atof(endTime.get_text().c_str());
-    const size_t startIndex = data.ImageWidth() * startRatio;
-    const size_t endIndex = data.ImageWidth() * endRatio;
-    for (size_t i = 0; i != data.ImageCount(); ++i) {
-      Image2DPtr image(new Image2D(*data.GetImage(i)));
-      const num_t addValue = 10.0 * image->GetStdDev();
-      for (size_t y = 0; y != image->Height(); ++y) {
-        for (size_t x = startIndex; x != endIndex; ++x)
-          image->AddValue(x, y, addValue);
-      }
+  dialog_ = std::make_unique<RangeInputDialog>(
+      *this, "Enter affected timerange (ratios):", 0.25, 0.5);
+  dialog_->signal_response().connect([this](int response) {
+    if (response == Gtk::ResponseType::OK) {
+      RangeInputDialog& dialog = static_cast<RangeInputDialog&>(*dialog_);
+      TimeFrequencyData data(GetActiveData());
+      const double startRatio = dialog.GetStart();
+      const double endRatio = dialog.GetEnd();
+      const size_t startIndex = data.ImageWidth() * startRatio;
+      const size_t endIndex = data.ImageWidth() * endRatio;
+      for (size_t i = 0; i != data.ImageCount(); ++i) {
+        Image2DPtr image(new Image2D(*data.GetImage(i)));
+        const num_t addValue = 10.0 * image->GetStdDev();
+        for (size_t y = 0; y != image->Height(); ++y) {
+          for (size_t x = startIndex; x != endIndex; ++x)
+            image->AddValue(x, y, addValue);
+        }
 
-      data.SetImage(i, std::move(image));
-    }
-    for (size_t i = 0; i != data.MaskCount(); ++i) {
-      Mask2DPtr mask(new Mask2D(*data.GetMask(i)));
-      for (size_t y = 0; y != mask->Height(); ++y) {
-        for (size_t x = startIndex; x != endIndex; ++x)
-          mask->SetValue(x, y, true);
+        data.SetImage(i, std::move(image));
       }
-      data.SetMask(i, std::move(mask));
+      for (size_t i = 0; i != data.MaskCount(); ++i) {
+        Mask2DPtr mask(new Mask2D(*data.GetMask(i)));
+        for (size_t y = 0; y != mask->Height(); ++y) {
+          for (size_t x = startIndex; x != endIndex; ++x)
+            mask->SetValue(x, y, true);
+        }
+        data.SetMask(i, std::move(mask));
+      }
+      _controller->TFController().SetNewData(
+          data, _timeFrequencyWidget.GetMaskedHeatMap().GetSelectedMetaData());
+      _timeFrequencyWidget.Update();
     }
-    _controller->TFController().SetNewData(
-        data, _timeFrequencyWidget.GetMaskedHeatMap().GetSelectedMetaData());
-    _timeFrequencyWidget.Update();
-  }
+    dialog_.reset();
+  });
+  dialog_->show();
 }
 
 void RFIGuiWindow::onAddNaNs() {
@@ -769,8 +787,9 @@ void RFIGuiWindow::onShowStats() {
       }
     }
     s << "Total unflagged power: " << power << "\n";
-    Gtk::MessageDialog dialog(*this, s.str(), false, Gtk::MESSAGE_INFO);
-    dialog.run();
+    dialog_ = std::make_unique<Gtk::MessageDialog>(*this, s.str(), false,
+                                                   Gtk::MessageType::INFO);
+    dialog_->show();
   }
 }
 
@@ -797,10 +816,12 @@ void RFIGuiWindow::onPlotSingularValuesPressed() {
 }
 
 void RFIGuiWindow::ShowHistogram(HistogramCollection& histogramCollection) {
-  if (_histogramWindow == nullptr)
+  if (_histogramWindow == nullptr) {
     _histogramWindow.reset(new HistogramWindow(histogramCollection));
-  else
+    _histogramWindow->set_hide_on_close(true);
+  } else {
     _histogramWindow->SetStatistics(histogramCollection);
+  }
   _histogramWindow->show();
 }
 
@@ -808,6 +829,7 @@ void RFIGuiWindow::onImagePropertiesPressed() {
   _imagePropertiesWindow.reset(
       new ImagePropertiesWindow(_timeFrequencyWidget.GetHeatMapWidget(),
                                 "Time-frequency plotting options"));
+  _imagePropertiesWindow->set_hide_on_close(true);
   _imagePropertiesWindow->show();
 }
 
@@ -1032,20 +1054,25 @@ void RFIGuiWindow::onUnrollPhaseButtonPressed() {
 }
 
 void RFIGuiWindow::showError(const std::string& description) {
-  Gtk::MessageDialog dialog(*this, description, false, Gtk::MESSAGE_ERROR);
-  dialog.run();
+  dialog_ = std::make_unique<Gtk::MessageDialog>(*this, description, false,
+                                                 Gtk::MessageType::ERROR);
+  dialog_->show();
 }
 
 void RFIGuiWindow::onSimulate() {
-  SimulateDialog simDialog;
-  if (simDialog.run() == Gtk::RESPONSE_OK) {
-    _controller->TFController().SetNewData(
-        simDialog.Make(),
-        TimeFrequencyMetaDataPtr(new TimeFrequencyMetaData()));
-    const char* name = "Simulated test set";
-    _controller->TFController().Plot().SetTitleText(name);
-    SetBaselineInfo(true, false, name, name);
-  }
+  dialog_ = std::make_unique<SimulateDialog>(*this);
+  dialog_->signal_response().connect([this](int response) {
+    if (response == Gtk::ResponseType::OK) {
+      SimulateDialog& dialog = static_cast<SimulateDialog&>(*dialog_);
+      _controller->TFController().SetNewData(
+          dialog.Make(), TimeFrequencyMetaDataPtr(new TimeFrequencyMetaData()));
+      const char* name = "Simulated test set";
+      _controller->TFController().Plot().SetTitleText(name);
+      SetBaselineInfo(true, false, name, name);
+    }
+    dialog_.reset();
+  });
+  dialog_->show();
 }
 
 void RFIGuiWindow::onStoreData() {
@@ -1115,32 +1142,43 @@ void RFIGuiWindow::onZoomOut() {
 }
 
 void RFIGuiWindow::onZoomSelect() {
-  MaskedHeatMap& heatMap = _timeFrequencyWidget.GetMaskedHeatMap();
-  if (!heatMap.HasImage()) return;
-  const Image2DCPtr image = heatMap.GetImage2D();
-  const size_t nTimes = image->Width();
-  const size_t nChannels = image->Height();
-  std::unique_ptr<NumInputDialog> dialog(
-      new NumInputDialog("Select zoom region", "Start timestep: ", 0.0));
-  if (dialog->run() != Gtk::RESPONSE_OK) return;
-  const double startTimestep = dialog->Value();
-  dialog.reset(
-      new NumInputDialog("Select zoom region", "End timestep: ", nTimes));
-  if (dialog->run() != Gtk::RESPONSE_OK) return;
-  const double endTimestep = dialog->Value();
-  dialog.reset(
-      new NumInputDialog("Select zoom region", "Start channel: ", 0.0));
-  if (dialog->run() != Gtk::RESPONSE_OK) return;
-  const double startChannel = dialog->Value();
-  dialog.reset(
-      new NumInputDialog("Select zoom region", "End channel: ", nChannels));
-  if (dialog->run() != Gtk::RESPONSE_OK) return;
-  const double endChannel = dialog->Value();
-  double x1, y1, x2, y2;
-  heatMap.ImageToUnit(startTimestep, startChannel, x1, y1);
-  heatMap.ImageToUnit(endTimestep, endChannel, x2, y2);
-  heatMap.ZoomTo(x1, y1, x2, y2);
-  _timeFrequencyWidget.Update();
+  MaskedHeatMap& heat_map = _timeFrequencyWidget.GetMaskedHeatMap();
+  if (!heat_map.HasImage()) return;
+  const Image2DCPtr image = heat_map.GetImage2D();
+  const size_t n_times = image->Width();
+  dialog_ = std::make_unique<RangeInputDialog>(*this, "Select zoom time range",
+                                               0.0, n_times);
+  dialog_->signal_response().connect([this](int response) {
+    if (response == Gtk::ResponseType::OK) {
+      RangeInputDialog& dialog = static_cast<RangeInputDialog&>(*dialog_);
+      const double start_timestep = dialog.GetStart();
+      const double end_timestep = dialog.GetEnd();
+      MaskedHeatMap& heat_map = _timeFrequencyWidget.GetMaskedHeatMap();
+      if (!heat_map.HasImage()) return;
+      const Image2DCPtr image = heat_map.GetImage2D();
+      const size_t n_channels = image->Height();
+      dialog_ = std::make_unique<RangeInputDialog>(
+          *this, "Select zoom channel range", 0.0, n_channels);
+      dialog_->signal_response().connect([this, start_timestep,
+                                          end_timestep](int response) {
+        if (response == Gtk::ResponseType::OK) {
+          RangeInputDialog& dialog = static_cast<RangeInputDialog&>(*dialog_);
+          const double start_channel = dialog.GetStart();
+          const double end_channel = dialog.GetEnd();
+          double x1, y1, x2, y2;
+          MaskedHeatMap& heat_map = _timeFrequencyWidget.GetMaskedHeatMap();
+          if (!heat_map.HasImage()) return;
+          heat_map.ImageToUnit(start_timestep, start_channel, x1, y1);
+          heat_map.ImageToUnit(end_timestep, end_channel, x2, y2);
+          heat_map.ZoomTo(x1, y1, x2, y2);
+          _timeFrequencyWidget.Update();
+        }
+        dialog_.reset();
+      });
+      dialog_->show();
+    }
+  });
+  dialog_->show();
 }
 
 void RFIGuiWindow::onTFZoomChanged() {
@@ -1152,7 +1190,9 @@ void RFIGuiWindow::onTFZoomChanged() {
 }
 
 void RFIGuiWindow::onHelpAbout() {
-  Gtk::AboutDialog aboutDialog;
+  about_dialog_ = std::make_unique<Gtk::AboutDialog>();
+  Gtk::AboutDialog& aboutDialog =
+      static_cast<Gtk::AboutDialog&>(*about_dialog_);
 
   std::vector<Glib::ustring> authors;
   authors.push_back("André Offringa <offringa@gmail.com>");
@@ -1162,14 +1202,14 @@ void RFIGuiWindow::onHelpAbout() {
       std::string(AOFLAGGER_VERSION_DATE_STR).substr(0, 4);
   aboutDialog.set_copyright("Copyright 2008 - " + release_year +
                             " A. R. Offringa");
-  aboutDialog.set_license_type(Gtk::LICENSE_GPL_3_0);
+  aboutDialog.set_license_type(Gtk::License::GPL_3_0);
   aboutDialog.set_logo_icon_name("aoflagger");
   aboutDialog.set_program_name("AOFlagger's RFI Gui");
   aboutDialog.set_version("AOFlagger " AOFLAGGER_VERSION_STR
                           " (" AOFLAGGER_VERSION_DATE_STR ") ");
   aboutDialog.set_website("https://readthedocs.org/projects/aoflagger/");
 
-  aboutDialog.run();
+  aboutDialog.show();
 }
 
 void RFIGuiWindow::onExecutePythonStrategy() {
@@ -1200,74 +1240,70 @@ void RFIGuiWindow::onSelectImage() {
 }
 
 void RFIGuiWindow::updateTFVisualizationMenu() {
-  Gtk::Menu& menu = _menu->VisualizationMenu();
-  const std::vector<Gtk::Widget*> children = menu.get_children();
-  for (Gtk::Widget* child : children) menu.remove(*child);
+  Gio::Menu& menu = *_menu->VisualizationMenu();
 
-  _tfVisualizationMenuItems.clear();
-  Gtk::RadioButtonGroup group;
+  menu.remove_all();
+  visualization_selection_action_ =
+      Gio::SimpleAction::create_radio_integer("tfvis", 0);
   for (size_t i = 0; i != _controller->TFController().VisualizationCount();
        ++i) {
-    const std::string label =
+    const std::string& label =
         _controller->TFController().GetVisualizationLabel(i);
-    _tfVisualizationMenuItems.emplace_back(std::unique_ptr<Gtk::RadioMenuItem>(
-        new Gtk::RadioMenuItem(group, label)));
-    Gtk::RadioMenuItem& item = *_tfVisualizationMenuItems.back();
-    item.signal_activate().connect(
-        sigc::mem_fun(*this, &RFIGuiWindow::onSelectImage));
-    menu.add(item);
+    menu.append(label, "win.tfvis(" + std::to_string(i) + ")");
   }
+  visualization_selection_action_->signal_change_state().connect(
+      [this](const Glib::VariantBase& variant) { onSelectImage(); });
 
-  _menu->SetSelectVisualizationSensitive(_tfVisualizationMenuItems.size() > 1);
-
-  _tfVisualizationMenuItems.front()->activate();
-  menu.show_all_children();
+  _menu->SetSelectVisualizationSensitive(
+      _controller->TFController().VisualizationCount() > 1);
 }
 
 void RFIGuiWindow::onToggleImage() {
   size_t index = getActiveTFVisualization();
   ++index;
-  if (index == _tfVisualizationMenuItems.size()) index = 0;
-  _tfVisualizationMenuItems[index]->set_active(true);
+  if (index == _controller->TFController().VisualizationCount()) index = 0;
+  visualization_selection_action_->set_state(Glib::Variant<int>::create(index));
 }
 
 size_t RFIGuiWindow::getActiveTFVisualization() {
-  for (size_t index = 0; index != _tfVisualizationMenuItems.size(); ++index) {
-    if (_tfVisualizationMenuItems[index]->get_active()) return index;
-  }
-  return 0;
+  int value;
+  visualization_selection_action_->get_state(value);
+  return value;
 }
 
 void RFIGuiWindow::onStrategyNewEmpty() {
-  if (askToSaveChanges()) {
+  askToSaveChanges([this]() {
     _controller->NewEmptyStrategy();
     _strategyEditor.SetText("");
     _strategyEditor.ResetChangedStatus();
     _menu->ActivateStrategyMode();
-  }
+  });
 }
 
 void RFIGuiWindow::onStrategyNewTemplate() {
-  if (askToSaveChanges()) {
+  askToSaveChanges([this]() {
     _controller->NewTemplateStrategy();
     _strategyEditor.SetText(_controller->GetWorkStrategyText());
     _strategyEditor.ResetChangedStatus();
     _menu->ActivateStrategyMode();
-  }
+  });
 }
 
 void RFIGuiWindow::onStrategyNewDefault() {
-  if (askToSaveChanges()) {
+  askToSaveChanges([this]() {
     _controller->NewDefaultStrategy();
     _strategyEditor.SetText(_controller->GetWorkStrategyText());
     _strategyEditor.ResetChangedStatus();
     _menu->ActivateStrategyMode();
-  }
+  });
 }
 
 void RFIGuiWindow::onStrategyOpen() {
-  if (askToSaveChanges()) {
-    Gtk::FileChooserDialog dialog("Select strategy to open");
+  askToSaveChanges([this]() {
+    dialog_ =
+        std::make_unique<Gtk::FileChooserDialog>("Select strategy to open");
+    Gtk::FileChooserDialog& dialog =
+        static_cast<Gtk::FileChooserDialog&>(*dialog_);
     dialog.set_transient_for(*this);
 
     auto filter_text = Gtk::FileFilter::create();
@@ -1276,22 +1312,26 @@ void RFIGuiWindow::onStrategyOpen() {
     dialog.add_filter(filter_text);
 
     // Add response buttons the the dialog:
-    dialog.add_button("_Cancel", Gtk::RESPONSE_CANCEL);
-    dialog.add_button("_Open", Gtk::RESPONSE_OK);
+    dialog.add_button("_Cancel", Gtk::ResponseType::CANCEL);
+    dialog.add_button("_Open", Gtk::ResponseType::OK);
+    dialog.signal_response().connect([this](int response) {
+      if (response == Gtk::ResponseType::OK) {
+        Gtk::FileChooserDialog& dialog =
+            static_cast<Gtk::FileChooserDialog&>(*dialog_);
+        _controller->OpenStrategy(dialog.get_file()->get_path());
+        _strategyEditor.SetText(_controller->GetWorkStrategyText());
+        _strategyEditor.ResetChangedStatus();
+        _menu->ActivateStrategyMode();
+      }
+      dialog_.reset();
+    });
 
-    const int result = dialog.run();
-
-    if (result == Gtk::RESPONSE_OK) {
-      _controller->OpenStrategy(dialog.get_filename());
-      _strategyEditor.SetText(_controller->GetWorkStrategyText());
-      _strategyEditor.ResetChangedStatus();
-      _menu->ActivateStrategyMode();
-    }
-  }
+    dialog.show();
+  });
 }
 
 void RFIGuiWindow::onStrategyOpenDefault(const std::string& name) {
-  if (askToSaveChanges()) {
+  askToSaveChanges([this, name]() {
     const TelescopeFile::TelescopeId id =
         TelescopeFile::TelescopeIdFromName(name);
     const std::string filename = TelescopeFile::FindStrategy(id);
@@ -1304,7 +1344,7 @@ void RFIGuiWindow::onStrategyOpenDefault(const std::string& name) {
       _strategyEditor.ResetChangedStatus();
       _menu->ActivateStrategyMode();
     }
-  }
+  });
 }
 
 void RFIGuiWindow::onStrategySave() {
@@ -1318,53 +1358,70 @@ void RFIGuiWindow::onStrategySave() {
 }
 
 void RFIGuiWindow::onStrategySaveAs() {
-  Gtk::FileChooserDialog dialog("Select filename for strategy",
-                                Gtk::FILE_CHOOSER_ACTION_SAVE);
+  dialog_ = std::make_unique<Gtk::FileChooserDialog>(
+      "Select filename for strategy", Gtk::FileChooser::Action::SAVE);
+  Gtk::FileChooserDialog& dialog =
+      static_cast<Gtk::FileChooserDialog&>(*dialog_);
   dialog.set_transient_for(*this);
-  dialog.add_button("_Cancel", Gtk::RESPONSE_CANCEL);
-  dialog.add_button("_Save", Gtk::RESPONSE_ACCEPT);
+  dialog.add_button("_Cancel", Gtk::ResponseType::CANCEL);
+  dialog.add_button("_Save", Gtk::ResponseType::ACCEPT);
 
   auto filter_text = Gtk::FileFilter::create();
   filter_text->set_name("Lua strategy files (*.lua)");
   filter_text->add_mime_type("text/x-lua");
   dialog.add_filter(filter_text);
-  dialog.set_do_overwrite_confirmation(true);
   if (_controller->HasOpenStrategy())
     dialog.set_current_name(_controller->StrategyFilename());
 
-  const int result = dialog.run();
+  dialog.signal_response().connect([this](int response) {
+    if (response == Gtk::ResponseType::ACCEPT) {
+      Gtk::FileChooserDialog& dialog =
+          static_cast<Gtk::FileChooserDialog&>(*dialog_);
+      _controller->SetWorkStrategyText(_strategyEditor.GetText());
+      _controller->SaveStrategyAs(dialog.get_file()->get_path());
+      _strategyEditor.ResetChangedStatus();
+    }
+    dialog_.reset();
+  });
 
-  if (result == Gtk::RESPONSE_ACCEPT) {
-    _controller->SetWorkStrategyText(_strategyEditor.GetText());
-    _controller->SaveStrategyAs(dialog.get_filename());
-    _strategyEditor.ResetChangedStatus();
-  }
+  dialog.show();
 }
 
 void RFIGuiWindow::handleAveraging(bool spectrally) {
   if (HasImage()) {
-    Gtk::MessageDialog dialog("Enter averaging factor", false,
-                              Gtk::MessageType::MESSAGE_QUESTION,
-                              Gtk::ButtonsType::BUTTONS_OK_CANCEL);
-    Gtk::Entry entry;
-    entry.set_text("2");
-    entry.set_max_width_chars(8);
-    dialog.get_message_area()->pack_end(entry);
-    entry.show();
-    if (dialog.run() == Gtk::RESPONSE_OK) {
-      const int factor = std::atoi(entry.get_text().c_str());
-      if (factor > 1) {
-        TimeFrequencyData data =
-            _controller->TFController().GetActiveDataFullSize();
-        const TimeFrequencyMetaDataPtr meta(new TimeFrequencyMetaData(
-            *_timeFrequencyWidget.GetMaskedHeatMap().GetFullMetaData()));
-        if (spectrally)
-          algorithms::downsample_masked(data, meta.get(), 1, factor);
-        else
-          algorithms::downsample_masked(data, meta.get(), factor, 1);
-        _controller->TFController().SetNewData(data, meta);
-        _timeFrequencyWidget.Update();
+    dialog_ = std::make_unique<NumInputDialog>(
+        spectrally ? "Frequency averaging" : "Time averaging", *this,
+        "Enter averaging factor", 2);
+    dialog_->signal_response().connect([this, spectrally](int response) {
+      if (response == Gtk::ResponseType::OK) {
+        NumInputDialog& dialog = static_cast<NumInputDialog&>(*dialog_);
+        const int factor = dialog.Value();
+        if (factor > 1) {
+          TimeFrequencyData data =
+              _controller->TFController().GetActiveDataFullSize();
+          const TimeFrequencyMetaDataPtr meta(new TimeFrequencyMetaData(
+              *_timeFrequencyWidget.GetMaskedHeatMap().GetFullMetaData()));
+          if (spectrally)
+            algorithms::downsample_masked(data, meta.get(), 1, factor);
+          else
+            algorithms::downsample_masked(data, meta.get(), factor, 1);
+          _controller->TFController().SetNewData(data, meta);
+          _timeFrequencyWidget.Update();
+        }
       }
-    }
+      dialog_.reset();
+    });
+  }
+  dialog_->show();
+}
+
+void RFIGuiWindow::predictResidual() {
+  if (HasImage()) {
+    TimeFrequencyData data =
+        _controller->TFController().GetActiveDataFullSize();
+    algorithms::PredictResidual(data);
+    _controller->TFController().SetNewData(
+        data, _timeFrequencyWidget.GetMaskedHeatMap().GetFullMetaData());
+    _timeFrequencyWidget.Update();
   }
 }
