@@ -14,7 +14,7 @@
 
 class SimulateDialog : public Gtk::Dialog {
  public:
-  SimulateDialog();
+  SimulateDialog(Gtk::Window& parent);
   ~SimulateDialog() {}
 
   TimeFrequencyData Make() const;
