@@ -8,19 +8,22 @@
 
 #include <gtkmm/box.h>
 
-class TimeFrequencyWidget : public Gtk::VBox {
+class TimeFrequencyWidget : public Gtk::Box {
  public:
-  explicit TimeFrequencyWidget(MaskedHeatMap& plot) : _heatMap() {
+  explicit TimeFrequencyWidget(MaskedHeatMap& plot)
+      : Gtk::Box(Gtk::Orientation::VERTICAL), _heatMap() {
     _heatMap.SetPlot(plot);
     _timePlotWidget.SetPlot(_timePlot);
     _timePlotWidget.set_size_request(200, 60);
     _timePlot.XAxis().SetShow(false);
-    pack_start(_timePlotWidget, Gtk::PACK_EXPAND_WIDGET);
+    append(_timePlotWidget);
+    _timePlotWidget.set_expand(true);
     EnableTimePlot();
 
     GetMaskedHeatMap().SetShowTitle(true);
     _heatMap.set_size_request(200, 200);
-    pack_start(_heatMap, Gtk::PACK_EXPAND_WIDGET);
+    append(_heatMap);
+    _heatMap.set_expand(true);
     _heatMap.show();
   }
 
