@@ -228,7 +228,7 @@ class Baseline {
     num_t dx = antenna1.x - antenna2.x;
     num_t dy = antenna1.y - antenna2.y;
     num_t dz = antenna1.z - antenna2.z;
-    return sqrtn(dx * dx + dy * dy + dz * dz);
+    return std::sqrt(dx * dx + dy * dy + dz * dz);
   }
   num_t Angle() const {
     num_t dz = antenna1.z - antenna2.z;
@@ -238,8 +238,8 @@ class Baseline {
     num_t transf = 1.0 / (antenna1.z - antenna2.z);
     num_t dx = (antenna1.x - antenna2.x) * transf;
     num_t dy = (antenna1.y - antenna2.y) * transf;
-    num_t length = sqrtn(dx * dx + dy * dy + 1.0);
-    return acosn(1.0 / length);
+    num_t length = std::sqrt(dx * dx + dy * dy + 1.0);
+    return std::acos(1.0 / length);
   }
   num_t DeltaX() const { return antenna2.x - antenna1.x; }
   num_t DeltaY() const { return antenna2.y - antenna1.y; }
@@ -268,11 +268,11 @@ class RightAscension {
     value = fmod(value, 2.0 * M_PInl);
     if (value < 0.0) value += 2.0 * M_PInl;
     std::stringstream s;
-    s << (int)floorn(value * 12.0 / M_PInl) << ':';
-    int d2 = (int)floornl(fmodnl(value * 12.0 * 60.0 / M_PInl, 60.0));
+    s << (int)std::floor(value * 12.0 / M_PInl) << ':';
+    int d2 = (int)std::floor(std::fmod(value * 12.0 * 60.0 / M_PInl, 60.0));
     if (d2 < 10) s << '0';
     s << d2 << ':';
-    numl_t d3 = fmodnl(value * 12.0 * 60.0 * 60.0 / M_PInl, 60.0);
+    numl_t d3 = std::fmod(value * 12.0 * 60.0 * 60.0 / M_PInl, 60.0);
     if (d3 < 10.0) s << '0';
     s << d3;
     return s.str();
@@ -290,12 +290,12 @@ class Declination {
       s << '+';
     else
       s << '-';
-    value = fabsnl(value);
-    s << (int)floornl(value * 180.0 / M_PIn) << '.';
-    int d2 = (int)fmodnl(value * 180.0 * 60.0 / M_PIn, 60.0);
+    value = std::fabs(value);
+    s << (int)std::floor(value * 180.0 / M_PIn) << '.';
+    int d2 = (int)std::fmod(value * 180.0 * 60.0 / M_PIn, 60.0);
     if (d2 < 10) s << '0';
     s << d2 << '.';
-    numl_t d3 = fmodnl(value * 180.0 * 60.0 * 60.0 / M_PIn, 60.0);
+    numl_t d3 = std::fmod(value * 180.0 * 60.0 * 60.0 / M_PIn, 60.0);
     if (d3 < 10.0) s << '0';
     s << d3;
     return s.str();
