@@ -127,6 +127,20 @@ class TimeFrequencyData {
     return data;
   }
 
+  static TimeFrequencyData FromStokes(const Image2DCPtr& i,
+                                      const Image2DCPtr& q,
+                                      const Image2DCPtr& u,
+                                      const Image2DCPtr& v) {
+    TimeFrequencyData data;
+    data._complexRepresentation = AmplitudePart;
+    data._data.reserve(4);
+    data._data.emplace_back(aocommon::Polarization::StokesI, i);
+    data._data.emplace_back(aocommon::Polarization::StokesQ, q);
+    data._data.emplace_back(aocommon::Polarization::StokesU, u);
+    data._data.emplace_back(aocommon::Polarization::StokesV, v);
+    return data;
+  }
+
   static TimeFrequencyData FromLinear(size_t polarizationCount,
                                       Image2DCPtr* realImages,
                                       Image2DCPtr* imagImages) {
@@ -682,6 +696,8 @@ class TimeFrequencyData {
 
   void Trim(unsigned timeStart, unsigned freqStart, unsigned timeEnd,
             unsigned freqEnd) {
+    if (timeStart > timeEnd) std::swap(timeStart, timeEnd);
+    if (freqStart > freqEnd) std::swap(freqStart, freqEnd);
     for (PolarizedTimeFrequencyData& data : _data) {
       if (data._images[0])
         data._images[0].reset(new Image2D(
